import * as i6 from '@angular/common';
import { CommonModule } from '@angular/common';
import * as i0 from '@angular/core';
import { Component, ChangeDetectionStrategy, Inject } from '@angular/core';
import * as i7 from '@angular/google-maps';
import { GoogleMapsModule } from '@angular/google-maps';
import * as i8 from '@angular/material/card';
import { MatCardModule } from '@angular/material/card';
import * as i1 from '@angular/material/dialog';
import { MAT_DIALOG_DATA, MatDialogModule } from '@angular/material/dialog';
import * as i9 from '@angular/material/table';
import { MatTableModule } from '@angular/material/table';
import * as i10 from '@angular/material/sort';
import { MatSortModule } from '@angular/material/sort';
import * as i5 from '@angular/router';
import * as i3 from '@smallstack/common-components';
import { FlattenPipe, JsonByPathPipe, JsonStringPipe, LoadingElementDirective, ObjectArrayValuePipe, OverlayComponent, UppercaseSpacePipe } from '@smallstack/common-components';
import { Logger } from '@smallstack/core-common';
import * as i2 from '@smallstack/i18n-components';
import { I18nComponent, CurrencyComponent, DateComponent, DurationComponent } from '@smallstack/i18n-components';
import { QRCodeDialogComponent } from '@smallstack/qrcode-components';
import { PageableCrudStore } from '@smallstack/store';
import { LIST_CONTAINER_PAGE_SIZE_OPTIONS, isNonEmptyStoreSearch, ListContainerComponent, LoaderComponent, MatSortStoreDirective, StorePropertyComponent } from '@smallstack/store-components';
import { MarkdownViewerComponent } from '@smallstack/text-components';
import { IconComponent } from '@smallstack/theme-components';
import * as i1$1 from '@smallstack/typesystem-client';
import { ShowForPermissionDirective } from '@smallstack/user-components';
import { convertGeoPointToLatLng, onlyUnique, cloneObject, randomInteger } from '@smallstack/utils';
import { WidgetTreeComponent, BaseWidgetComponent, WidgetTag, WidgetChildComponent } from '@smallstack/widget-core';
import { firstValueFrom } from 'rxjs';
import { S as SocketNames } from './smallstack-data-widgets-smallstack-data-widgets-fa483882.mjs';
import { DataTableV2RenderTypes } from './smallstack-data-widgets-data-table-v2-widget-configuration-f344179a.mjs';
import '@smallstack/axios-api-client';
import '@smallstack/form-shared';

class DataTableV2DialogComponent {
    constructor(data, dialogRef) {
        this.data = data;
        this.dialogRef = dialogRef;
        data.widgetRendererOptions.dialogRef = dialogRef;
    }
    close() {
        if (this.data.widgetRendererOptions?.editMode === true)
            this.dialogRef.close(this.data.cmsComponent);
        else
            this.dialogRef.close();
    }
    static { this.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "16.2.8", ngImport: i0, type: DataTableV2DialogComponent, deps: [{ token: MAT_DIALOG_DATA }, { token: i1.MatDialogRef }], target: i0.ɵɵFactoryTarget.Component }); }
    static { this.ɵcmp = i0.ɵɵngDeclareComponent({ minVersion: "14.0.0", version: "16.2.8", type: DataTableV2DialogComponent, isStandalone: true, selector: "ng-component", ngImport: i0, template: "<div mat-dialog-content>\n  <smallstack-widget-tree\n    [(widget)]=\"data.cmsComponent\"\n    [widgetRendererOptions]=\"data.widgetRendererOptions\"\n    [context]=\"data.context\"\n  ></smallstack-widget-tree>\n</div>\n<div mat-dialog-actions class=\"flex flex-row justify-end\">\n  <button (click)=\"close()\" class=\"btn btn-primary\">\n    <smallstack-i18n data=\"@@actions.close\"></smallstack-i18n>\n  </button>\n</div>\n", styles: [".mat-mdc-dialog-content{height:calc(100% - 40px);max-height:unset}\n"], dependencies: [{ kind: "ngmodule", type: CommonModule }, { kind: "component", type: WidgetTreeComponent, selector: "smallstack-widget-tree", inputs: ["widgetRendererOptions", "widget", "context", "globals", "connections", "rootSockets"], outputs: ["connectionsChange", "widgetChange"] }, { kind: "component", type: I18nComponent, selector: "smallstack-i18n", inputs: ["data", "showMissingKey", "replacers", "locale", "translationStore"] }, { kind: "ngmodule", type: MatDialogModule }, { kind: "directive", type: i1.MatDialogContent, selector: "[mat-dialog-content], mat-dialog-content, [matDialogContent]" }, { kind: "directive", type: i1.MatDialogActions, selector: "[mat-dialog-actions], mat-dialog-actions, [matDialogActions]", inputs: ["align"] }], changeDetection: i0.ChangeDetectionStrategy.OnPush }); }
}
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "16.2.8", ngImport: i0, type: DataTableV2DialogComponent, decorators: [{
            type: Component,
            args: [{ changeDetection: ChangeDetectionStrategy.OnPush, standalone: true, imports: [CommonModule, WidgetTreeComponent, I18nComponent, MatDialogModule], template: "<div mat-dialog-content>\n  <smallstack-widget-tree\n    [(widget)]=\"data.cmsComponent\"\n    [widgetRendererOptions]=\"data.widgetRendererOptions\"\n    [context]=\"data.context\"\n  ></smallstack-widget-tree>\n</div>\n<div mat-dialog-actions class=\"flex flex-row justify-end\">\n  <button (click)=\"close()\" class=\"btn btn-primary\">\n    <smallstack-i18n data=\"@@actions.close\"></smallstack-i18n>\n  </button>\n</div>\n", styles: [".mat-mdc-dialog-content{height:calc(100% - 40px);max-height:unset}\n"] }]
        }], ctorParameters: function () { return [{ type: undefined, decorators: [{
                    type: Inject,
                    args: [MAT_DIALOG_DATA]
                }] }, { type: i1.MatDialogRef }]; } });

class DataTableV2WidgetComponent extends BaseWidgetComponent {
    get columns() {
        const columns = this.listProperties?.map((lp) => lp.columnName);
        if (this.data?.showEditButton || this.data?.showDeleteButton)
            columns.push("actions");
        if (this.data?.allowMultiDelete || this.data?.showCheckboxes)
            columns.splice(0, 0, "multiSelect");
        return columns;
    }
    constructor(matDialog, notificationService, storeRegistry, activatedRoute, routerUtilService, frontendTypeRegistry, breakPointService) {
        super();
        this.matDialog = matDialog;
        this.notificationService = notificationService;
        this.storeRegistry = storeRegistry;
        this.activatedRoute = activatedRoute;
        this.routerUtilService = routerUtilService;
        this.frontendTypeRegistry = frontendTypeRegistry;
        // google maps related stuff
        this.convertGeoPointToLatLng = convertGeoPointToLatLng;
        this.googleMapsOverlayOpened = false;
        this.listProperties = [];
        this.loading = true;
        this.errors = [];
        this.mappingArray = {};
        this.pageSizeOptions = LIST_CONTAINER_PAGE_SIZE_OPTIONS;
        this.selectedIds = [];
        this.selectedModels = [];
        this.WidgetTag = WidgetTag;
        this.isMobile$ = breakPointService.isMobile$;
        this.subscription.add(this.data$.subscribe(async (data) => {
            await this.setData(data);
        }));
    }
    async setData(data) {
        if (data)
            await this.evaluateConfiguration(data);
    }
    async handleSocketData(socketName, data) {
        switch (socketName) {
            case SocketNames.openCreationDialog:
                await this.openEditor()();
                break;
            case SocketNames.tableData:
                this.manualTableData = data;
                this.cdr.markForCheck();
                break;
            case SocketNames.searchQuery:
                this.manualTableData = undefined;
                await this.store.search(data);
                this.cdr.markForCheck();
                break;
            case SocketNames.reload:
                await this.store.reload();
                break;
        }
    }
    qrCodeDialog(value, prefix = "") {
        this.matDialog.closeAll();
        this.matDialog.open(QRCodeDialogComponent, { data: prefix + value, autoFocus: false });
    }
    async openDialog(lp, model) {
        this.matDialog.closeAll();
        if (lp.dialogUrlSyncParameter)
            await this.routerUtilService.addSearchParameter(lp.dialogUrlSyncParameter, model.id);
        void this.matDialog
            .open(DataTableV2DialogComponent, {
            width: lp.dialogWidth,
            height: lp.dialogHeight,
            autoFocus: false,
            data: {
                cmsComponent: lp.dialogComponent,
                widgetRendererOptions: {
                    editMode: this.editMode
                },
                context: model
            }
        })
            .afterClosed()
            .subscribe(async (component) => {
            if (this.editMode === true && component) {
                this.data.listProperties[lp.index].dialogComponent = component;
                this.dataChange.emit(this.data);
            }
            if (lp.dialogUrlSyncParameter)
                await this.routerUtilService.removeSearchParameter(lp.dialogUrlSyncParameter);
        });
    }
    openEditor(model) {
        return async () => {
            await this.frontendTypeRegistry.openEditor(this.smallstackType.path, model);
            if (model)
                await this.store.reloadOne(model.id);
            else
                await this.store.load();
        };
    }
    deleteData(elem) {
        return async () => {
            const answer = await this.notificationService.popup.confirmation("Datensatz löschen", "Soll der Datensatz wirklich gelöscht werden?", [
                { label: "@@actions.no", color: "primary", value: false },
                { label: "@@actions.yes", color: "error", value: true }
            ]);
            if (answer === true && this.store instanceof PageableCrudStore) {
                await this.store.delete(elem.id);
                await this.store.load();
            }
        };
    }
    deleteManyData(ids) {
        return async () => {
            const plural = ids.length !== 1;
            const answer = await this.notificationService.popup.confirmation(ids.length + " " + (plural ? "Datensätze" : "Datensatz") + " löschen", plural
                ? "Möchten Sie wirklich die " + ids.length + " selektierten Datensätze löschen?"
                : "Soll der Datensatz wirklich gelöscht werden?", [
                { label: "@@actions.no", classes: "btn btn-outline", value: false },
                { label: "@@actions.yes", classes: "btn btn-error", value: true }
            ]);
            if (answer === true && this.store instanceof PageableCrudStore) {
                await this.store.deleteMany(ids);
                await this.store.load();
            }
        };
    }
    async toggleAll(checkboxEvent) {
        const target = checkboxEvent.target;
        if (target.checked)
            this.selectedIds = (await firstValueFrom(this.store.currentPage$)).map((data) => data.id);
        else
            this.selectedIds = [];
        this.selectedModels = this.selectedIds.map((id) => this.store.getById(id));
        this.cdr.markForCheck();
    }
    toggleEntry(id, checkboxEvent) {
        const target = checkboxEvent.target;
        if (target.checked)
            this.selectedIds = onlyUnique([...this.selectedIds, id]);
        else
            this.selectedIds = this.selectedIds.filter((selectedId) => selectedId !== id);
        this.selectedModels = this.selectedIds.map((id) => this.store.getById(id));
    }
    setWidgetListProperty(propertyName, newWidget) {
        const index = this.listProperties.findIndex((lp) => lp.property === propertyName);
        if (index === -1)
            throw new Error("Could not find list property by propertyName: " + propertyName);
        this.listProperties[index].widget = newWidget;
        this.data.listProperties = this.listProperties;
        this.cdr.detectChanges();
    }
    async evaluateConfiguration(data) {
        try {
            this.loading = true;
            this.errors = [];
            // get store
            if (data.typeName) {
                this.smallstackType = await this.frontendTypeRegistry.getTypeByPath(data.typeName);
                if (!this.smallstackType)
                    this.errors.push("@@widgets.dataTable.errors.typeNotFound");
                this.store = this.storeRegistry.getStore(data.typeName);
                if (!this.store)
                    this.errors.push("@@widgets.dataTable.errors.storeNotFound");
                this.schema = await this.frontendTypeRegistry.getSchema(data.typeName);
                if (!this.schema)
                    this.errors.push("@@widgets.dataTable.errors.schemaNotFound");
                if (this.errors.length !== 0)
                    return;
            }
            // subscribe to store paging
            this.subscription.add(this.store?.pagination$.subscribe(() => {
                this.selectedIds = [];
                this.selectedModels = [];
            }));
            // eval list properties
            const listProperties = cloneObject(data.listProperties);
            if (listProperties instanceof Array && listProperties.length > 0) {
                // check for qrCodes (we'll prefix the row names for these)
                listProperties.forEach((lp, index) => {
                    // set some defaults
                    if (lp.renderer === DataTableV2RenderTypes.QR_CODE)
                        lp.sortable = false;
                    if (lp.renderer === DataTableV2RenderTypes.WIDGET && lp.widgetContextType === undefined)
                        lp.widgetContextType = "property";
                    // set a unique (recognizable) column name
                    lp.columnName = lp.property + "_" + randomInteger(0, 500000);
                    lp.index = index;
                });
                this.listProperties = listProperties;
            }
            else
                Logger.debug("DataTableWidget", "no listProperties configured");
            // eval auto sorting
            if (data.autoSortProperty && this.store) {
                if (this.store instanceof PageableCrudStore)
                    this.store.sortBy(data.autoSortProperty);
            }
            // eval initial page size
            if (data.setPageSize && this.store) {
                if (this.store instanceof PageableCrudStore)
                    this.store.setPageSize(data.setPageSize);
            }
            this.listProperties?.forEach((lp) => {
                const secondDimension = {};
                if (lp.valueIconPairArray)
                    lp.valueIconPairArray.forEach((element) => {
                        secondDimension[element.value] = element.icon;
                    });
                this.mappingArray[lp.property] = secondDimension;
            });
            // start subscribing to query params for url sync (e.g. open dialog action)
            this.subscription.add(this.activatedRoute.queryParams.subscribe(async (params) => {
                for (let index = 0; index < this.listProperties.length; index++) {
                    if (this.listProperties[index].dialogUrlSyncParameter &&
                        params[this.listProperties[index].dialogUrlSyncParameter]) {
                        await this.openDialog(this.listProperties[index], await this.store.get(params[this.listProperties[index].dialogUrlSyncParameter]));
                    }
                }
            }));
            // eval filters
            if (isNonEmptyStoreSearch(data.searchQuery))
                await this.store.search(data.searchQuery);
        }
        catch (e) {
            this.errors.push(e.message);
        }
        finally {
            this.loading = false;
            this.cdr.markForCheck();
        }
    }
    static { this.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "16.2.8", ngImport: i0, type: DataTableV2WidgetComponent, deps: [{ token: i1.MatDialog }, { token: i2.NotificationService }, { token: i3.StoreRegistry }, { token: i5.ActivatedRoute }, { token: i3.RouterUtilService }, { token: i1$1.FrontendTypeRegistry }, { token: i3.BreakpointService }], target: i0.ɵɵFactoryTarget.Component }); }
    static { this.ɵcmp = i0.ɵɵngDeclareComponent({ minVersion: "14.0.0", version: "16.2.8", type: DataTableV2WidgetComponent, isStandalone: true, selector: "ng-component", usesInheritance: true, ngImport: i0, template: "<smallstack-loader *ngIf=\"loading; else content\"></smallstack-loader>\n<ng-template #content>\n  <ng-container *ngIf=\"errors?.length > 0\">\n    <div *ngFor=\"let error of errors\">\n      {{ error }}\n    </div>\n  </ng-container>\n  <ng-container *ngIf=\"store && listProperties?.length > 0 && listProperties[0].property; else widgetNotConfigured\">\n    <smallstack-list-container [store]=\"store\" [pageSize]=\"data?.setPageSize\" [pageSizeOptions]=\"pageSizeOptions\">\n      <ng-template #content>\n        <div class=\"scrolling-table\">\n          <table\n            mat-table\n            [dataSource]=\"manualTableData || store.currentPage$\"\n            matSort\n            [smallstackMatSortStore]=\"store\"\n            *ngIf=\"store\"\n          >\n            <ng-container [matColumnDef]=\"lp.columnName\" *ngFor=\"let lp of listProperties\">\n              <ng-container *ngIf=\"lp.property && lp.title; else unconfiguredRow\">\n                <th\n                  mat-header-cell\n                  *matHeaderCellDef\n                  [class]=\"'header-cell-' + lp.property\"\n                  [mat-sort-header]=\"lp.property\"\n                  [disabled]=\"!lp.sortable\"\n                >\n                  <ng-container *ngIf=\"lp.title; else noTitle\"\n                    ><smallstack-i18n [data]=\"lp.title\" style=\"white-space: nowrap\"></smallstack-i18n\n                  ></ng-container>\n                  <ng-template #noTitle>{{ lp.property | uppercaseSpace }}</ng-template>\n                </th>\n                <td mat-cell *matCellDef=\"let element; index as i\" [class]=\"'cell-' + lp.property\">\n                  <ng-container [ngSwitch]=\"lp.renderer\">\n                    <ng-container *ngSwitchCase=\"'date'\">\n                      <smallstack-date\n                        [format]=\"lp.rendererDateFormat\"\n                        [timestamp]=\"element | jsonByPath: lp.property\"\n                        style=\"white-space: nowrap\"\n                      ></smallstack-date>\n                    </ng-container>\n                    <ng-container *ngSwitchCase=\"'duration'\">\n                      <smallstack-duration [duration]=\"element | jsonByPath: lp.property\"></smallstack-duration>\n                    </ng-container>\n                    <ng-container *ngSwitchCase=\"'icon'\">\n                      <div>\n                        <smallstack-icon\n                          size=\"24\"\n                          [alias]=\"\n                            mappingArray[lp.property][element[lp.property]]\n                              ? mappingArray[lp.property][element[lp.property]]\n                              : lp.defaultIcon\n                          \"\n                        ></smallstack-icon>\n                      </div>\n                    </ng-container>\n                    <ng-container *ngSwitchCase=\"'image'\">\n                      <smallstack-overlay #overlay>\n                        <div class=\"card card-bordered card-compact shadow-xl bg-white\">\n                          <div class=\"card-body\">\n                            <img [src]=\"element | jsonByPath: lp.property\" class=\"w-80\" />\n                          </div>\n                        </div>\n                      </smallstack-overlay>\n                      <img\n                        class=\"mask mask-square w-16 cursor-pointer\"\n                        [src]=\"element | jsonByPath: lp.property\"\n                        (click)=\"overlay.openOverlay()\"\n                      />\n                    </ng-container>\n                    <ng-container *ngSwitchCase=\"'storeProperty'\">\n                      <smallstack-store-property\n                        [storeName]=\"lp.rendererStorePropertyStore\"\n                        [property]=\"lp.rendererStorePropertyProperty\"\n                        [modelId]=\"element | flatten: lp.property\"\n                      >\n                      </smallstack-store-property>\n                    </ng-container>\n                    <ng-container *ngSwitchCase=\"'i18n'\">\n                      <ng-container *ngIf=\"lp.i18nPrefix; else unPrefixed\">\n                        <smallstack-i18n\n                          [data]=\"(lp.i18nPrefix ? lp.i18nPrefix : '') + element | jsonByPath: lp.property\"\n                        ></smallstack-i18n>\n                      </ng-container>\n                      <ng-template #unPrefixed>\n                        <smallstack-i18n [data]=\"element | jsonByPath: lp.property\"></smallstack-i18n>\n                      </ng-template>\n                    </ng-container>\n                    <ng-container *ngSwitchCase=\"'qrCode'\">\n                      <button class=\"btn-action\" (click)=\"qrCodeDialog(element[lp.property], lp.qrCodePrefix)\">\n                        <smallstack-icon alias=\"qrcode\"></smallstack-icon>\n                      </button>\n                    </ng-container>\n                    <ng-container *ngSwitchCase=\"'dialog'\">\n                      <button class=\"btn-action\" (click)=\"openDialog(lp, element)\">\n                        <smallstack-icon [name]=\"lp.dialogButtonIcon\"></smallstack-icon>\n                      </button>\n                    </ng-container>\n                    <ng-container *ngSwitchCase=\"'link'\">\n                      <a\n                        href=\"{{ element | jsonByPath: lp.property }}\"\n                        target=\"{{ lp.openLinkInNewWindow ? '_blank' : undefined }}\"\n                      >\n                        <ng-container *ngIf=\"lp.linkLabel; else noLabel\">\n                          {{ lp.linkLabel }}\n                        </ng-container>\n                        <ng-template #noLabel>\n                          {{ element | jsonByPath: lp.property }}\n                        </ng-template>\n                      </a>\n                    </ng-container>\n                    <ng-container *ngSwitchCase=\"'boolean'\">\n                      <smallstack-icon\n                        name=\"checkmark--v1\"\n                        theme=\"color\"\n                        size=\"24\"\n                        *ngIf=\"(element | jsonByPath: lp.property) === true; else falsy\"\n                      >\n                      </smallstack-icon>\n                      <ng-template #falsy>\n                        <smallstack-icon name=\"delete-sign--v1\" theme=\"color\" size=\"24\"> </smallstack-icon>\n                      </ng-template>\n                    </ng-container>\n                    <ng-container *ngSwitchCase=\"'markdown'\">\n                      <smallstack-markdown-viewer\n                        [text]=\"element | jsonByPath: lp.property\"\n                      ></smallstack-markdown-viewer>\n                    </ng-container>\n                    <ng-container *ngSwitchCase=\"'googleMap'\">\n                      <div style=\"cursor: pointer; position: relative\" (click)=\"overlay.openOverlay()\">\n                        <div style=\"position: absolute; width: 100%; height: 100%; z-index: 100\"></div>\n                        <google-map\n                          [width]=\"lp.googleMapsPreviewWidth\"\n                          [height]=\"lp.googleMapsPreviewHeight\"\n                          [zoom]=\"14\"\n                          [center]=\"convertGeoPointToLatLng(element[lp.property].geoJson)\"\n                          [options]=\"{\n                            gestureHandling: 'none',\n                            disableDefaultUI: true,\n                            styles: [\n                              {\n                                featureType: 'poi',\n                                elementType: 'labels',\n                                stylers: [{ visibility: 'off' }]\n                              }\n                            ]\n                          }\"\n                        >\n                          <map-marker\n                            [position]=\"convertGeoPointToLatLng(element[lp.property].geoJson)\"\n                            [clickable]=\"false\"\n                          ></map-marker>\n                        </google-map>\n                      </div>\n                      <smallstack-overlay #overlay>\n                        <mat-card appearance=\"outlined\" class=\"flex flex-col space-y-5\">\n                          <google-map\n                            width=\"350px\"\n                            height=\"350px\"\n                            [zoom]=\"16\"\n                            [center]=\"convertGeoPointToLatLng(element[lp.property].geoJson)\"\n                          >\n                            <map-marker\n                              [position]=\"convertGeoPointToLatLng(element[lp.property].geoJson)\"\n                              [clickable]=\"false\"\n                            ></map-marker>\n                          </google-map>\n                          <button class=\"btn btn-primary\" (click)=\"overlay.closeOverlay()\">\n                            <smallstack-i18n data=\"@@actions.close\"></smallstack-i18n>\n                          </button>\n                        </mat-card>\n                      </smallstack-overlay>\n                    </ng-container>\n                    <ng-container *ngSwitchCase=\"'widget'\">\n                      <ng-container *ngIf=\"lp.widget\">\n                        <smallstack-widget-tree\n                          *ngIf=\"lp.widgetContextType === 'full'; else propertyContext\"\n                          [widget]=\"lp.widget\"\n                          (widgetChange)=\"setWidgetListProperty(lp.property, $event)\"\n                          [widgetRendererOptions]=\"{\n                            editMode$: widgetTreeService.editMode$\n                          }\"\n                          [context]=\"{ model: element }\"\n                          [globals]=\"{ model: element }\"\n                        ></smallstack-widget-tree>\n                        <ng-template #propertyContext>\n                          <smallstack-widget-tree\n                            [widget]=\"lp.widget\"\n                            (widgetChange)=\"setWidgetListProperty(lp.property, $event)\"\n                            [widgetRendererOptions]=\"{\n                              editMode$: widgetTreeService.editMode$\n                            }\"\n                            [context]=\"{ model: element | jsonByPath: lp.property }\"\n                            [globals]=\"{ model: element }\"\n                          ></smallstack-widget-tree\n                        ></ng-template>\n                      </ng-container>\n                    </ng-container>\n                    <ng-container *ngSwitchCase=\"'currency'\">\n                      <smallstack-currency\n                        [iso]=\"lp.currency ? lp.currency : 'EUR'\"\n                        [cents]=\"element[lp.property]\"\n                      ></smallstack-currency>\n                    </ng-container>\n                    <ng-container *ngSwitchCase=\"'valueMapping'\">\n                      <span>{{\n                        lp.mappingArray | objectArrayValue: \"value\":element[lp.property]:\"mappedValue\":lp.defaultValue\n                      }}</span>\n                    </ng-container>\n                    <ng-container *ngSwitchDefault>\n                      {{ element | flatten: lp.property | jsonstring }}\n                    </ng-container>\n                  </ng-container>\n                </td>\n              </ng-container>\n              <ng-template #unconfiguredRow> Unconfigured Row </ng-template>\n            </ng-container>\n            <ng-container matColumnDef=\"multiSelect\" sticky>\n              <th mat-header-cell *matHeaderCellDef class=\"checkboxes\">\n                <ng-container *ngIf=\"store.currentPage$ | async as currentPageLength\">\n                  <input\n                    type=\"checkbox\"\n                    class=\"checkbox checkbox-primary checkbox-sm\"\n                    [indeterminate]=\"selectedIds.length !== currentPageLength.length && selectedIds.length !== 0\"\n                    [checked]=\"selectedIds.length === currentPageLength.length\"\n                    (change)=\"toggleAll($event)\"\n                    data-test=\"check-all\"\n                  />\n                </ng-container>\n              </th>\n              <td mat-cell *matCellDef=\"let element; let i = index\" class=\"checkboxes\">\n                <input\n                  type=\"checkbox\"\n                  class=\"checkbox checkbox-primary checkbox-sm\"\n                  [checked]=\"selectedIds.includes(element.id)\"\n                  (change)=\"toggleEntry(element.id, $event)\"\n                  attr.data-testid=\"checkbox-{{ i }}\"\n                />\n              </td>\n            </ng-container>\n            <ng-container matColumnDef=\"actions\" stickyEnd>\n              <th mat-header-cell *matHeaderCellDef class=\"header-cell-actions\">\n                <smallstack-i18n data=\"@@nouns.actions\"></smallstack-i18n>\n              </th>\n              <td mat-cell *matCellDef=\"let element\" class=\"cell-actions\">\n                <div class=\"flex flex-row gap-2\">\n                  <ng-container *ngIf=\"data?.showDeleteButton\">\n                    <button\n                      class=\"btn-action btn-error\"\n                      [loadingFn]=\"deleteData(element)\"\n                      *showForPermission=\"smallstackType.permissions.delete\"\n                      data-test=\"delete-entry\"\n                    >\n                      <smallstack-icon alias=\"delete\"></smallstack-icon>\n                    </button>\n                  </ng-container>\n                  <ng-container *ngIf=\"data?.showEditButton\">\n                    <button\n                      class=\"btn-action btn-primary\"\n                      [loadingFn]=\"openEditor(element)\"\n                      *showForPermission=\"smallstackType.permissions.update\"\n                      data-test=\"edit-entry\"\n                    >\n                      <smallstack-icon alias=\"edit\"></smallstack-icon>\n                    </button>\n                  </ng-container>\n                  <smallstack-widget-child\n                    [(data)]=\"data\"\n                    property=\"actionWidget\"\n                    [context]=\"{ model: element }\"\n                    (dataChange)=\"dataChange.emit($event)\"\n                  ></smallstack-widget-child>\n                </div>\n              </td>\n            </ng-container>\n\n            <tr mat-header-row *matHeaderRowDef=\"columns\"></tr>\n            <tr mat-row *matRowDef=\"let row; columns: columns\"></tr>\n          </table>\n        </div>\n      </ng-template>\n      <ng-template #listActions>\n        <div class=\"flex flex-row flex-wrap items-start pl-3\">\n          <ng-container *ngIf=\"selectedIds.length > 0\">\n            <ng-container *ngIf=\"data.allowMultiDelete\">\n              <button\n                class=\"btn-action btn-error\"\n                [loadingFn]=\"deleteManyData(selectedIds)\"\n                matTooltip=\"Markierte Datens\u00E4tze l\u00F6schen\"\n                *showForPermission=\"smallstackType.permissions.delete\"\n              >\n                <smallstack-icon alias=\"delete\"></smallstack-icon>\n              </button>\n            </ng-container>\n            <smallstack-widget-child\n              property=\"listActionsComponent\"\n              [(data)]=\"data\"\n              [context]=\"{selectedIds, selectedModels}\"\n              [widgetTags]=\"[WidgetTag.ICON, WidgetTag.CONTAINER]\"\n              (dataChange)=\"dataChange.emit($event)\"\n            ></smallstack-widget-child>\n          </ng-container>\n        </div>\n      </ng-template>\n    </smallstack-list-container>\n    <div\n      style=\"text-align: end; padding-top: 20px; padding-right: 15px\"\n      *showForPermission=\"smallstackType.permissions.create\"\n    >\n      <button\n        *ngIf=\"data?.showCreateButton !== false\"\n        class=\"btn btn-primary btn-sm\"\n        [loadingFn]=\"openEditor()\"\n        data-test=\"create\"\n      >\n        <smallstack-i18n data=\"@@actions.create\"></smallstack-i18n>\n      </button>\n    </div>\n  </ng-container>\n  <ng-template #widgetNotConfigured>\n    <div style=\"height: 60px\" class=\"flex flex-col justify-center items-center\">\n      <i><smallstack-i18n data=\"@@widgets.dataTable.errors.notConfiguredYet\"></smallstack-i18n></i>\n    </div>\n  </ng-template>\n</ng-template>\n", styles: ["table{width:100%}td{padding:5px!important}td:first-of-type{padding-left:24px!important}.cell-actions{white-space:nowrap}.checkboxes{width:60px}\n"], dependencies: [{ kind: "ngmodule", type: CommonModule }, { kind: "directive", type: i6.NgForOf, selector: "[ngFor][ngForOf]", inputs: ["ngForOf", "ngForTrackBy", "ngForTemplate"] }, { kind: "directive", type: i6.NgIf, selector: "[ngIf]", inputs: ["ngIf", "ngIfThen", "ngIfElse"] }, { kind: "directive", type: i6.NgSwitch, selector: "[ngSwitch]", inputs: ["ngSwitch"] }, { kind: "directive", type: i6.NgSwitchCase, selector: "[ngSwitchCase]", inputs: ["ngSwitchCase"] }, { kind: "directive", type: i6.NgSwitchDefault, selector: "[ngSwitchDefault]" }, { kind: "pipe", type: i6.AsyncPipe, name: "async" }, { kind: "component", type: CurrencyComponent, selector: "smallstack-currency", inputs: ["iso", "value", "euros", "cents"] }, { kind: "component", type: DateComponent, selector: "smallstack-date", inputs: ["timestamp", "format"] }, { kind: "component", type: DurationComponent, selector: "smallstack-duration", inputs: ["start", "end", "duration"] }, { kind: "pipe", type: FlattenPipe, name: "flatten" }, { kind: "ngmodule", type: GoogleMapsModule }, { kind: "component", type: i7.GoogleMap, selector: "google-map", inputs: ["height", "width", "mapTypeId", "center", "zoom", "options"], outputs: ["mapInitialized", "authFailure", "boundsChanged", "centerChanged", "mapClick", "mapDblclick", "mapDrag", "mapDragend", "mapDragstart", "headingChanged", "idle", "maptypeidChanged", "mapMousemove", "mapMouseout", "mapMouseover", "projectionChanged", "mapRightclick", "tilesloaded", "tiltChanged", "zoomChanged"], exportAs: ["googleMap"] }, { kind: "directive", type: i7.MapMarker, selector: "map-marker", inputs: ["title", "position", "label", "clickable", "options", "icon", "visible"], outputs: ["animationChanged", "mapClick", "clickableChanged", "cursorChanged", "mapDblclick", "mapDrag", "mapDragend", "draggableChanged", "mapDragstart", "flatChanged", "iconChanged", "mapMousedown", "mapMouseout", "mapMouseover", "mapMouseup", "positionChanged", "mapRightclick", "shapeChanged", "titleChanged", "visibleChanged", "zindexChanged"], exportAs: ["mapMarker"] }, { kind: "component", type: I18nComponent, selector: "smallstack-i18n", inputs: ["data", "showMissingKey", "replacers", "locale", "translationStore"] }, { kind: "component", type: IconComponent, selector: "smallstack-icon", inputs: ["theme", "size", "name", "alias", "action", "actionSize", "spinning", "actionSpinning", "color", "themeColor", "actionColor", "badge", "dynamic", "badgeColor"], outputs: ["iconError"] }, { kind: "pipe", type: JsonByPathPipe, name: "jsonByPath" }, { kind: "pipe", type: JsonStringPipe, name: "jsonstring" }, { kind: "component", type: ListContainerComponent, selector: "smallstack-list-container", inputs: ["paginatorPosition", "showPager", "pageSize", "pageSizeOptions", "showEmpty", "store"], outputs: ["pageSizeChange"] }, { kind: "component", type: LoaderComponent, selector: "smallstack-loader", inputs: ["loading", "color", "size", "loadingText"] }, { kind: "directive", type: LoadingElementDirective, selector: "[loadingFn]", inputs: ["loadingFn", "isLoading"], exportAs: ["loadingFn"] }, { kind: "component", type: MarkdownViewerComponent, selector: "smallstack-markdown-viewer", inputs: ["text"] }, { kind: "ngmodule", type: MatCardModule }, { kind: "component", type: i8.MatCard, selector: "mat-card", inputs: ["appearance"], exportAs: ["matCard"] }, { kind: "ngmodule", type: MatTableModule }, { kind: "component", type: i9.MatTable, selector: "mat-table, table[mat-table]", exportAs: ["matTable"] }, { kind: "directive", type: i9.MatHeaderCellDef, selector: "[matHeaderCellDef]" }, { kind: "directive", type: i9.MatHeaderRowDef, selector: "[matHeaderRowDef]", inputs: ["matHeaderRowDef", "matHeaderRowDefSticky"] }, { kind: "directive", type: i9.MatColumnDef, selector: "[matColumnDef]", inputs: ["sticky", "matColumnDef"] }, { kind: "directive", type: i9.MatCellDef, selector: "[matCellDef]" }, { kind: "directive", type: i9.MatRowDef, selector: "[matRowDef]", inputs: ["matRowDefColumns", "matRowDefWhen"] }, { kind: "directive", type: i9.MatHeaderCell, selector: "mat-header-cell, th[mat-header-cell]" }, { kind: "directive", type: i9.MatCell, selector: "mat-cell, td[mat-cell]" }, { kind: "component", type: i9.MatHeaderRow, selector: "mat-header-row, tr[mat-header-row]", exportAs: ["matHeaderRow"] }, { kind: "component", type: i9.MatRow, selector: "mat-row, tr[mat-row]", exportAs: ["matRow"] }, { kind: "ngmodule", type: MatSortModule }, { kind: "directive", type: i10.MatSort, selector: "[matSort]", inputs: ["matSortDisabled", "matSortActive", "matSortStart", "matSortDirection", "matSortDisableClear"], outputs: ["matSortChange"], exportAs: ["matSort"] }, { kind: "component", type: i10.MatSortHeader, selector: "[mat-sort-header]", inputs: ["disabled", "mat-sort-header", "arrowPosition", "start", "sortActionDescription", "disableClear"], exportAs: ["matSortHeader"] }, { kind: "directive", type: MatSortStoreDirective, selector: "[smallstackMatSortStore]", inputs: ["smallstackMatSortStore"] }, { kind: "pipe", type: ObjectArrayValuePipe, name: "objectArrayValue" }, { kind: "component", type: OverlayComponent, selector: "smallstack-overlay", inputs: ["hasBackdrop"] }, { kind: "component", type: StorePropertyComponent, selector: "smallstack-store-property", inputs: ["store", "storeName", "modelId", "property", "notFound", "showNotFound"] }, { kind: "pipe", type: UppercaseSpacePipe, name: "uppercaseSpace" }, { kind: "component", type: WidgetChildComponent, selector: "smallstack-widget-child", inputs: ["data", "context", "property", "widgetTags"], outputs: ["dataChange"] }, { kind: "component", type: WidgetTreeComponent, selector: "smallstack-widget-tree", inputs: ["widgetRendererOptions", "widget", "context", "globals", "connections", "rootSockets"], outputs: ["connectionsChange", "widgetChange"] }, { kind: "directive", type: ShowForPermissionDirective, selector: "[showForPermission]", inputs: ["showForPermission", "showForPermissionTenantId"] }], changeDetection: i0.ChangeDetectionStrategy.OnPush }); }
}
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "16.2.8", ngImport: i0, type: DataTableV2WidgetComponent, decorators: [{
            type: Component,
            args: [{ changeDetection: ChangeDetectionStrategy.OnPush, standalone: true, imports: [
                        CommonModule,
                        CurrencyComponent,
                        DateComponent,
                        DurationComponent,
                        FlattenPipe,
                        GoogleMapsModule,
                        I18nComponent,
                        IconComponent,
                        JsonByPathPipe,
                        JsonStringPipe,
                        ListContainerComponent,
                        LoaderComponent,
                        LoadingElementDirective,
                        MarkdownViewerComponent,
                        MatCardModule,
                        MatTableModule,
                        MatSortModule,
                        MatSortStoreDirective,
                        ObjectArrayValuePipe,
                        OverlayComponent,
                        StorePropertyComponent,
                        UppercaseSpacePipe,
                        WidgetChildComponent,
                        WidgetTreeComponent,
                        ShowForPermissionDirective
                    ], template: "<smallstack-loader *ngIf=\"loading; else content\"></smallstack-loader>\n<ng-template #content>\n  <ng-container *ngIf=\"errors?.length > 0\">\n    <div *ngFor=\"let error of errors\">\n      {{ error }}\n    </div>\n  </ng-container>\n  <ng-container *ngIf=\"store && listProperties?.length > 0 && listProperties[0].property; else widgetNotConfigured\">\n    <smallstack-list-container [store]=\"store\" [pageSize]=\"data?.setPageSize\" [pageSizeOptions]=\"pageSizeOptions\">\n      <ng-template #content>\n        <div class=\"scrolling-table\">\n          <table\n            mat-table\n            [dataSource]=\"manualTableData || store.currentPage$\"\n            matSort\n            [smallstackMatSortStore]=\"store\"\n            *ngIf=\"store\"\n          >\n            <ng-container [matColumnDef]=\"lp.columnName\" *ngFor=\"let lp of listProperties\">\n              <ng-container *ngIf=\"lp.property && lp.title; else unconfiguredRow\">\n                <th\n                  mat-header-cell\n                  *matHeaderCellDef\n                  [class]=\"'header-cell-' + lp.property\"\n                  [mat-sort-header]=\"lp.property\"\n                  [disabled]=\"!lp.sortable\"\n                >\n                  <ng-container *ngIf=\"lp.title; else noTitle\"\n                    ><smallstack-i18n [data]=\"lp.title\" style=\"white-space: nowrap\"></smallstack-i18n\n                  ></ng-container>\n                  <ng-template #noTitle>{{ lp.property | uppercaseSpace }}</ng-template>\n                </th>\n                <td mat-cell *matCellDef=\"let element; index as i\" [class]=\"'cell-' + lp.property\">\n                  <ng-container [ngSwitch]=\"lp.renderer\">\n                    <ng-container *ngSwitchCase=\"'date'\">\n                      <smallstack-date\n                        [format]=\"lp.rendererDateFormat\"\n                        [timestamp]=\"element | jsonByPath: lp.property\"\n                        style=\"white-space: nowrap\"\n                      ></smallstack-date>\n                    </ng-container>\n                    <ng-container *ngSwitchCase=\"'duration'\">\n                      <smallstack-duration [duration]=\"element | jsonByPath: lp.property\"></smallstack-duration>\n                    </ng-container>\n                    <ng-container *ngSwitchCase=\"'icon'\">\n                      <div>\n                        <smallstack-icon\n                          size=\"24\"\n                          [alias]=\"\n                            mappingArray[lp.property][element[lp.property]]\n                              ? mappingArray[lp.property][element[lp.property]]\n                              : lp.defaultIcon\n                          \"\n                        ></smallstack-icon>\n                      </div>\n                    </ng-container>\n                    <ng-container *ngSwitchCase=\"'image'\">\n                      <smallstack-overlay #overlay>\n                        <div class=\"card card-bordered card-compact shadow-xl bg-white\">\n                          <div class=\"card-body\">\n                            <img [src]=\"element | jsonByPath: lp.property\" class=\"w-80\" />\n                          </div>\n                        </div>\n                      </smallstack-overlay>\n                      <img\n                        class=\"mask mask-square w-16 cursor-pointer\"\n                        [src]=\"element | jsonByPath: lp.property\"\n                        (click)=\"overlay.openOverlay()\"\n                      />\n                    </ng-container>\n                    <ng-container *ngSwitchCase=\"'storeProperty'\">\n                      <smallstack-store-property\n                        [storeName]=\"lp.rendererStorePropertyStore\"\n                        [property]=\"lp.rendererStorePropertyProperty\"\n                        [modelId]=\"element | flatten: lp.property\"\n                      >\n                      </smallstack-store-property>\n                    </ng-container>\n                    <ng-container *ngSwitchCase=\"'i18n'\">\n                      <ng-container *ngIf=\"lp.i18nPrefix; else unPrefixed\">\n                        <smallstack-i18n\n                          [data]=\"(lp.i18nPrefix ? lp.i18nPrefix : '') + element | jsonByPath: lp.property\"\n                        ></smallstack-i18n>\n                      </ng-container>\n                      <ng-template #unPrefixed>\n                        <smallstack-i18n [data]=\"element | jsonByPath: lp.property\"></smallstack-i18n>\n                      </ng-template>\n                    </ng-container>\n                    <ng-container *ngSwitchCase=\"'qrCode'\">\n                      <button class=\"btn-action\" (click)=\"qrCodeDialog(element[lp.property], lp.qrCodePrefix)\">\n                        <smallstack-icon alias=\"qrcode\"></smallstack-icon>\n                      </button>\n                    </ng-container>\n                    <ng-container *ngSwitchCase=\"'dialog'\">\n                      <button class=\"btn-action\" (click)=\"openDialog(lp, element)\">\n                        <smallstack-icon [name]=\"lp.dialogButtonIcon\"></smallstack-icon>\n                      </button>\n                    </ng-container>\n                    <ng-container *ngSwitchCase=\"'link'\">\n                      <a\n                        href=\"{{ element | jsonByPath: lp.property }}\"\n                        target=\"{{ lp.openLinkInNewWindow ? '_blank' : undefined }}\"\n                      >\n                        <ng-container *ngIf=\"lp.linkLabel; else noLabel\">\n                          {{ lp.linkLabel }}\n                        </ng-container>\n                        <ng-template #noLabel>\n                          {{ element | jsonByPath: lp.property }}\n                        </ng-template>\n                      </a>\n                    </ng-container>\n                    <ng-container *ngSwitchCase=\"'boolean'\">\n                      <smallstack-icon\n                        name=\"checkmark--v1\"\n                        theme=\"color\"\n                        size=\"24\"\n                        *ngIf=\"(element | jsonByPath: lp.property) === true; else falsy\"\n                      >\n                      </smallstack-icon>\n                      <ng-template #falsy>\n                        <smallstack-icon name=\"delete-sign--v1\" theme=\"color\" size=\"24\"> </smallstack-icon>\n                      </ng-template>\n                    </ng-container>\n                    <ng-container *ngSwitchCase=\"'markdown'\">\n                      <smallstack-markdown-viewer\n                        [text]=\"element | jsonByPath: lp.property\"\n                      ></smallstack-markdown-viewer>\n                    </ng-container>\n                    <ng-container *ngSwitchCase=\"'googleMap'\">\n                      <div style=\"cursor: pointer; position: relative\" (click)=\"overlay.openOverlay()\">\n                        <div style=\"position: absolute; width: 100%; height: 100%; z-index: 100\"></div>\n                        <google-map\n                          [width]=\"lp.googleMapsPreviewWidth\"\n                          [height]=\"lp.googleMapsPreviewHeight\"\n                          [zoom]=\"14\"\n                          [center]=\"convertGeoPointToLatLng(element[lp.property].geoJson)\"\n                          [options]=\"{\n                            gestureHandling: 'none',\n                            disableDefaultUI: true,\n                            styles: [\n                              {\n                                featureType: 'poi',\n                                elementType: 'labels',\n                                stylers: [{ visibility: 'off' }]\n                              }\n                            ]\n                          }\"\n                        >\n                          <map-marker\n                            [position]=\"convertGeoPointToLatLng(element[lp.property].geoJson)\"\n                            [clickable]=\"false\"\n                          ></map-marker>\n                        </google-map>\n                      </div>\n                      <smallstack-overlay #overlay>\n                        <mat-card appearance=\"outlined\" class=\"flex flex-col space-y-5\">\n                          <google-map\n                            width=\"350px\"\n                            height=\"350px\"\n                            [zoom]=\"16\"\n                            [center]=\"convertGeoPointToLatLng(element[lp.property].geoJson)\"\n                          >\n                            <map-marker\n                              [position]=\"convertGeoPointToLatLng(element[lp.property].geoJson)\"\n                              [clickable]=\"false\"\n                            ></map-marker>\n                          </google-map>\n                          <button class=\"btn btn-primary\" (click)=\"overlay.closeOverlay()\">\n                            <smallstack-i18n data=\"@@actions.close\"></smallstack-i18n>\n                          </button>\n                        </mat-card>\n                      </smallstack-overlay>\n                    </ng-container>\n                    <ng-container *ngSwitchCase=\"'widget'\">\n                      <ng-container *ngIf=\"lp.widget\">\n                        <smallstack-widget-tree\n                          *ngIf=\"lp.widgetContextType === 'full'; else propertyContext\"\n                          [widget]=\"lp.widget\"\n                          (widgetChange)=\"setWidgetListProperty(lp.property, $event)\"\n                          [widgetRendererOptions]=\"{\n                            editMode$: widgetTreeService.editMode$\n                          }\"\n                          [context]=\"{ model: element }\"\n                          [globals]=\"{ model: element }\"\n                        ></smallstack-widget-tree>\n                        <ng-template #propertyContext>\n                          <smallstack-widget-tree\n                            [widget]=\"lp.widget\"\n                            (widgetChange)=\"setWidgetListProperty(lp.property, $event)\"\n                            [widgetRendererOptions]=\"{\n                              editMode$: widgetTreeService.editMode$\n                            }\"\n                            [context]=\"{ model: element | jsonByPath: lp.property }\"\n                            [globals]=\"{ model: element }\"\n                          ></smallstack-widget-tree\n                        ></ng-template>\n                      </ng-container>\n                    </ng-container>\n                    <ng-container *ngSwitchCase=\"'currency'\">\n                      <smallstack-currency\n                        [iso]=\"lp.currency ? lp.currency : 'EUR'\"\n                        [cents]=\"element[lp.property]\"\n                      ></smallstack-currency>\n                    </ng-container>\n                    <ng-container *ngSwitchCase=\"'valueMapping'\">\n                      <span>{{\n                        lp.mappingArray | objectArrayValue: \"value\":element[lp.property]:\"mappedValue\":lp.defaultValue\n                      }}</span>\n                    </ng-container>\n                    <ng-container *ngSwitchDefault>\n                      {{ element | flatten: lp.property | jsonstring }}\n                    </ng-container>\n                  </ng-container>\n                </td>\n              </ng-container>\n              <ng-template #unconfiguredRow> Unconfigured Row </ng-template>\n            </ng-container>\n            <ng-container matColumnDef=\"multiSelect\" sticky>\n              <th mat-header-cell *matHeaderCellDef class=\"checkboxes\">\n                <ng-container *ngIf=\"store.currentPage$ | async as currentPageLength\">\n                  <input\n                    type=\"checkbox\"\n                    class=\"checkbox checkbox-primary checkbox-sm\"\n                    [indeterminate]=\"selectedIds.length !== currentPageLength.length && selectedIds.length !== 0\"\n                    [checked]=\"selectedIds.length === currentPageLength.length\"\n                    (change)=\"toggleAll($event)\"\n                    data-test=\"check-all\"\n                  />\n                </ng-container>\n              </th>\n              <td mat-cell *matCellDef=\"let element; let i = index\" class=\"checkboxes\">\n                <input\n                  type=\"checkbox\"\n                  class=\"checkbox checkbox-primary checkbox-sm\"\n                  [checked]=\"selectedIds.includes(element.id)\"\n                  (change)=\"toggleEntry(element.id, $event)\"\n                  attr.data-testid=\"checkbox-{{ i }}\"\n                />\n              </td>\n            </ng-container>\n            <ng-container matColumnDef=\"actions\" stickyEnd>\n              <th mat-header-cell *matHeaderCellDef class=\"header-cell-actions\">\n                <smallstack-i18n data=\"@@nouns.actions\"></smallstack-i18n>\n              </th>\n              <td mat-cell *matCellDef=\"let element\" class=\"cell-actions\">\n                <div class=\"flex flex-row gap-2\">\n                  <ng-container *ngIf=\"data?.showDeleteButton\">\n                    <button\n                      class=\"btn-action btn-error\"\n                      [loadingFn]=\"deleteData(element)\"\n                      *showForPermission=\"smallstackType.permissions.delete\"\n                      data-test=\"delete-entry\"\n                    >\n                      <smallstack-icon alias=\"delete\"></smallstack-icon>\n                    </button>\n                  </ng-container>\n                  <ng-container *ngIf=\"data?.showEditButton\">\n                    <button\n                      class=\"btn-action btn-primary\"\n                      [loadingFn]=\"openEditor(element)\"\n                      *showForPermission=\"smallstackType.permissions.update\"\n                      data-test=\"edit-entry\"\n                    >\n                      <smallstack-icon alias=\"edit\"></smallstack-icon>\n                    </button>\n                  </ng-container>\n                  <smallstack-widget-child\n                    [(data)]=\"data\"\n                    property=\"actionWidget\"\n                    [context]=\"{ model: element }\"\n                    (dataChange)=\"dataChange.emit($event)\"\n                  ></smallstack-widget-child>\n                </div>\n              </td>\n            </ng-container>\n\n            <tr mat-header-row *matHeaderRowDef=\"columns\"></tr>\n            <tr mat-row *matRowDef=\"let row; columns: columns\"></tr>\n          </table>\n        </div>\n      </ng-template>\n      <ng-template #listActions>\n        <div class=\"flex flex-row flex-wrap items-start pl-3\">\n          <ng-container *ngIf=\"selectedIds.length > 0\">\n            <ng-container *ngIf=\"data.allowMultiDelete\">\n              <button\n                class=\"btn-action btn-error\"\n                [loadingFn]=\"deleteManyData(selectedIds)\"\n                matTooltip=\"Markierte Datens\u00E4tze l\u00F6schen\"\n                *showForPermission=\"smallstackType.permissions.delete\"\n              >\n                <smallstack-icon alias=\"delete\"></smallstack-icon>\n              </button>\n            </ng-container>\n            <smallstack-widget-child\n              property=\"listActionsComponent\"\n              [(data)]=\"data\"\n              [context]=\"{selectedIds, selectedModels}\"\n              [widgetTags]=\"[WidgetTag.ICON, WidgetTag.CONTAINER]\"\n              (dataChange)=\"dataChange.emit($event)\"\n            ></smallstack-widget-child>\n          </ng-container>\n        </div>\n      </ng-template>\n    </smallstack-list-container>\n    <div\n      style=\"text-align: end; padding-top: 20px; padding-right: 15px\"\n      *showForPermission=\"smallstackType.permissions.create\"\n    >\n      <button\n        *ngIf=\"data?.showCreateButton !== false\"\n        class=\"btn btn-primary btn-sm\"\n        [loadingFn]=\"openEditor()\"\n        data-test=\"create\"\n      >\n        <smallstack-i18n data=\"@@actions.create\"></smallstack-i18n>\n      </button>\n    </div>\n  </ng-container>\n  <ng-template #widgetNotConfigured>\n    <div style=\"height: 60px\" class=\"flex flex-col justify-center items-center\">\n      <i><smallstack-i18n data=\"@@widgets.dataTable.errors.notConfiguredYet\"></smallstack-i18n></i>\n    </div>\n  </ng-template>\n</ng-template>\n", styles: ["table{width:100%}td{padding:5px!important}td:first-of-type{padding-left:24px!important}.cell-actions{white-space:nowrap}.checkboxes{width:60px}\n"] }]
        }], ctorParameters: function () { return [{ type: i1.MatDialog }, { type: i2.NotificationService }, { type: i3.StoreRegistry }, { type: i5.ActivatedRoute }, { type: i3.RouterUtilService }, { type: i1$1.FrontendTypeRegistry }, { type: i3.BreakpointService }]; } });

export { DataTableV2WidgetComponent };
//# sourceMappingURL=smallstack-data-widgets-data-table-v2-widget.component-345bdb36.mjs.map
