import * as i6 from '@angular/common';
import { CommonModule } from '@angular/common';
import * as i0 from '@angular/core';
import { Component, ChangeDetectionStrategy, Inject } from '@angular/core';
import * as i7 from '@angular/google-maps';
import { GoogleMapsModule } from '@angular/google-maps';
import * as i8 from '@angular/material/card';
import { MatCardModule } from '@angular/material/card';
import * as i1 from '@angular/material/dialog';
import { MAT_DIALOG_DATA } from '@angular/material/dialog';
import * as i10 from '@angular/material/sort';
import { MatSortModule } from '@angular/material/sort';
import * as i9 from '@angular/material/table';
import { MatTableModule } from '@angular/material/table';
import * as i5 from '@angular/router';
import { createPageFrom } from '@smallstack/api-shared';
import * as i1$1 from '@smallstack/axios-api-client';
import { TenantDataApi } from '@smallstack/axios-api-client';
import * as i3 from '@smallstack/common-components';
import { OverlayComponent, UppercaseSpacePipe, FlattenPipe, JsonStringPipe, LoadingElementDirective } from '@smallstack/common-components';
import { Logger } from '@smallstack/core-common';
import { FormEditorDialogComponent } from '@smallstack/form-components';
import * as i2 from '@smallstack/i18n-components';
import { I18nComponent, DateComponent } from '@smallstack/i18n-components';
import { QRCodeDialogComponent } from '@smallstack/qrcode-components';
import { PageableStore, PageableCrudStore } from '@smallstack/store';
import { LIST_CONTAINER_PAGE_SIZE_OPTIONS, isNonEmptyStoreSearch, LoaderComponent, ListContainerComponent, StorePropertyComponent, MatSortStoreDirective } from '@smallstack/store-components';
import { MarkdownViewerComponent } from '@smallstack/text-components';
import { IconComponent } from '@smallstack/theme-components';
import { F_CUSTOM } from '@smallstack/typesystem';
import { ShowForPermissionDirective } from '@smallstack/user-components';
import { convertGeoPointToLatLng, replaceVariablesInObject } from '@smallstack/utils';
import { WidgetTreeComponent, BaseWidgetComponent } from '@smallstack/widget-core';
import { DATA_SOURCE_DATATYPE, SocketNames, DATA_SOURCE_STORE, DATA_SOURCE_CONTEXT, DataTableRenderTypes } from './smallstack-data-widgets-configuration-fb0a53c4.mjs';

class DataTableDialogComponent {
    constructor(data, dialogRef) {
        this.data = data;
        this.dialogRef = dialogRef;
        data.widgetRendererOptions.dialogRef = dialogRef;
    }
    close() {
        if (this.data.widgetRendererOptions?.editMode === true)
            this.dialogRef.close(this.data.cmsComponent);
        else
            this.dialogRef.close();
    }
    static { this.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "16.2.8", ngImport: i0, type: DataTableDialogComponent, deps: [{ token: MAT_DIALOG_DATA }, { token: i1.MatDialogRef }], target: i0.ɵɵFactoryTarget.Component }); }
    static { this.ɵcmp = i0.ɵɵngDeclareComponent({ minVersion: "14.0.0", version: "16.2.8", type: DataTableDialogComponent, isStandalone: true, selector: "smallstack-data-table-dialog", ngImport: i0, template: "<div mat-dialog-content>\n  <smallstack-widget-tree\n    [(widget)]=\"data.cmsComponent\"\n    [widgetRendererOptions]=\"data.widgetRendererOptions\"\n    [context]=\"data.context\"\n  ></smallstack-widget-tree>\n</div>\n<div mat-dialog-actions class=\"flex flex-row justify-end\">\n  <button (click)=\"close()\" class=\"btn btn-primary\">\n    <smallstack-i18n data=\"@@actions.close\"></smallstack-i18n>\n  </button>\n</div>\n", styles: [".mat-mdc-dialog-content{height:calc(100% - 40px);max-height:unset}\n"], dependencies: [{ kind: "ngmodule", type: CommonModule }, { kind: "component", type: I18nComponent, selector: "smallstack-i18n", inputs: ["data", "showMissingKey", "replacers", "locale", "translationStore"] }, { kind: "component", type: WidgetTreeComponent, selector: "smallstack-widget-tree", inputs: ["widgetRendererOptions", "widget", "context", "globals", "connections", "rootSockets"], outputs: ["connectionsChange", "widgetChange"] }], changeDetection: i0.ChangeDetectionStrategy.OnPush }); }
}
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "16.2.8", ngImport: i0, type: DataTableDialogComponent, decorators: [{
            type: Component,
            args: [{ selector: "smallstack-data-table-dialog", changeDetection: ChangeDetectionStrategy.OnPush, standalone: true, imports: [CommonModule, I18nComponent, WidgetTreeComponent], template: "<div mat-dialog-content>\n  <smallstack-widget-tree\n    [(widget)]=\"data.cmsComponent\"\n    [widgetRendererOptions]=\"data.widgetRendererOptions\"\n    [context]=\"data.context\"\n  ></smallstack-widget-tree>\n</div>\n<div mat-dialog-actions class=\"flex flex-row justify-end\">\n  <button (click)=\"close()\" class=\"btn btn-primary\">\n    <smallstack-i18n data=\"@@actions.close\"></smallstack-i18n>\n  </button>\n</div>\n", styles: [".mat-mdc-dialog-content{height:calc(100% - 40px);max-height:unset}\n"] }]
        }], ctorParameters: function () { return [{ type: undefined, decorators: [{
                    type: Inject,
                    args: [MAT_DIALOG_DATA]
                }] }, { type: i1.MatDialogRef }]; } });

class DataTableWidgetComponent extends BaseWidgetComponent {
    constructor(matDialog, axiosApiClient, dataStore, notificationService, storeRegistry, activatedRoute, router, routerUtilService, translationStore) {
        super();
        this.matDialog = matDialog;
        this.axiosApiClient = axiosApiClient;
        this.dataStore = dataStore;
        this.notificationService = notificationService;
        this.storeRegistry = storeRegistry;
        this.activatedRoute = activatedRoute;
        this.router = router;
        this.routerUtilService = routerUtilService;
        this.translationStore = translationStore;
        // google maps related stuff
        this.convertGeoPointToLatLng = convertGeoPointToLatLng;
        this.googleMapsOverlayOpened = false;
        this.listProperties = [];
        this.loading = true;
        this.dataDeletePermission = "tenant.admin";
        this.dataEditPermission = "tenant.admin";
        this.dataCreatePermission = "tenant.admin";
        this.mappingArray = {};
        this.pageSizeOptions = LIST_CONTAINER_PAGE_SIZE_OPTIONS;
    }
    get columns() {
        if (this.data?.dataSource === DATA_SOURCE_DATATYPE && (this.data?.showEditButton || this.data?.showDeleteButton))
            return this.listProperties?.map((lp) => lp.columnName).concat("actions");
        else
            return this.listProperties?.map((lp) => lp.columnName);
    }
    async handleSocketData(socketName, data) {
        if (socketName === SocketNames.openCreationDialog)
            this.createNew();
    }
    async ngOnInit() {
        if (this.data) {
            // evaluate possible data sources
            if (this.data.dataSource === DATA_SOURCE_DATATYPE) {
                if (this.data.dataType) {
                    this.dataType = await this.axiosApiClient
                        .get(TenantDataApi)
                        .getDataType({ id: this.data.dataType })
                        .then((res) => res.data);
                    if (this.dataType) {
                        if (this.dataType.httpMethodPermissions?.putPermission)
                            this.dataEditPermission = this.dataType.httpMethodPermissions.putPermission;
                        if (this.dataType.httpMethodPermissions?.deletePermission)
                            this.dataDeletePermission = this.dataType.httpMethodPermissions.deletePermission;
                        if (this.dataType.httpMethodPermissions?.postPermission)
                            this.dataCreatePermission = this.dataType.httpMethodPermissions.postPermission;
                        this.store = this.dataStore.for(F_CUSTOM, this.dataType.path);
                        this.cdr.markForCheck();
                    }
                    else
                        Logger.debug("DataTableWidget", "datatype " + this.data.dataType + " not found");
                }
                else
                    Logger.debug("DataTableWidget", "no datatype configured");
            }
            else if (this.data.dataSource === DATA_SOURCE_STORE) {
                if (this.data.store) {
                    if (isNonEmptyStoreSearch(this.data.storeSearch))
                        this.store = this.storeRegistry.getStore(this.data.store).createSearch(replaceVariablesInObject(this.data.storeSearch, this.context, {
                            removeUnmappedContent: true
                        }));
                    else
                        this.store = this.storeRegistry.getStore(this.data.store);
                    if (!this.store)
                        Logger.debug("DataTableWidget", "store " + this.data.store + " not found");
                }
                else
                    Logger.debug("DataTableWidget", "no no store configured");
            }
            else if (this.data.dataSource === DATA_SOURCE_CONTEXT) {
                const objects = this.context[this.data.contextProperty];
                objects.forEach((val, index) => {
                    val.id = index;
                    return val;
                });
                this.store = new (class extends PageableStore {
                    async loadModels() {
                        return createPageFrom(objects);
                    }
                })();
            }
            // eval list properties
            if (this.data.listProperties instanceof Array && this.data.listProperties.length > 0) {
                // TODO: find a better solution for doubled but sortable column definitions
                // check for qrCodes (we'll prefix the row names for these)
                this.data.listProperties.forEach((lp) => {
                    if (lp.renderer === DataTableRenderTypes.QR_CODE) {
                        lp.columnName = "qrcode_" + lp.property;
                        lp.sortable = false;
                    }
                    else
                        lp.columnName = lp.property;
                });
                // check for invalid
                this.data.listProperties.forEach((lp) => {
                    if (lp.property === undefined) {
                        this.error = "no property set for entry " + JSON.stringify(lp);
                        return;
                    }
                });
                // check for duplicates
                const seen = new Set();
                const hasDuplicates = this.data.listProperties.some((currentObject) => {
                    return seen.size === seen.add(currentObject.columnName).size;
                });
                if (hasDuplicates)
                    this.error =
                        "Duplicated property names found: " +
                            this.data.listProperties.map((lp) => lp.columnName).join(", ");
                else
                    this.listProperties = this.data.listProperties;
            }
            else
                Logger.debug("DataTableWidget", "no listProperties configured");
            // eval autosorting
            if (this.data.autoSortProperty && this.store) {
                if (this.store instanceof PageableCrudStore)
                    this.store.sortBy(this.data.autoSortProperty);
            }
        }
        this.listProperties?.forEach((lp) => {
            const secondDimension = {};
            lp.valueIconPairArray?.forEach((element) => {
                secondDimension[element.value] = element.icon;
            });
            this.mappingArray[lp.columnName] = secondDimension;
        });
        // start subscribing to query params for url sync (e.g. open dialog action)
        void this.activatedRoute.queryParams.subscribe(async (params) => {
            for (const listProperty of this.listProperties) {
                if (listProperty.dialogUrlSyncParameter && params[listProperty.dialogUrlSyncParameter]) {
                    await this.openDialog(listProperty, await this.store.get(params[listProperty.dialogUrlSyncParameter]));
                }
            }
        });
        this.loading = false;
        this.cdr.markForCheck();
    }
    qrCodeDialog(value, prefix = "") {
        this.matDialog.closeAll();
        this.matDialog.open(QRCodeDialogComponent, { data: prefix + value, autoFocus: false });
    }
    async openDialog(lp, model) {
        this.matDialog.closeAll();
        if (lp.dialogUrlSyncParameter)
            await this.routerUtilService.addSearchParameter(lp.dialogUrlSyncParameter, model.id);
        void this.matDialog
            .open(DataTableDialogComponent, {
            width: lp.dialogWidth,
            height: lp.dialogHeight,
            autoFocus: false,
            data: {
                cmsComponent: lp.dialogComponent,
                widgetRendererOptions: {
                    editMode: this.editMode
                },
                context: model
            }
        })
            .afterClosed()
            .subscribe(async (component) => {
            if (this.editMode === true && component) {
                lp.dialogComponent = component;
                this.dataChange.emit(this.data);
            }
            if (lp.dialogUrlSyncParameter)
                await this.routerUtilService.removeSearchParameter(lp.dialogUrlSyncParameter);
        });
    }
    createNew() {
        const dialog = this.matDialog.open(FormEditorDialogComponent, {
            data: {
                schema: this.dataType.schema,
                title: "Neuen " + this.translationStore.translate(this.dataType.title) + " Datensatz anlegen",
                saveFn: async (newModel) => {
                    if (newModel && this.store instanceof PageableCrudStore) {
                        await this.store.create(newModel);
                        await this.store.load();
                        this.cdr.markForCheck();
                    }
                }
            },
            autoFocus: false
        });
        this.subscription.add(this.router.events.subscribe(() => {
            if (dialog)
                dialog.close();
        }));
    }
    editData(model) {
        return async () => {
            return new Promise((resolve) => {
                const dialog = this.matDialog.open(FormEditorDialogComponent, {
                    data: { schema: this.dataType.schema, title: "Datensatz bearbeiten", model },
                    autoFocus: false,
                    minWidth: "400px"
                });
                void dialog.afterClosed().subscribe(async (putModel) => {
                    if (putModel && this.store instanceof PageableCrudStore) {
                        await this.store.put(putModel);
                        await this.store.load();
                        this.cdr.markForCheck();
                    }
                    resolve();
                });
                this.subscription.add(this.router.events.subscribe(() => {
                    if (dialog)
                        dialog.close();
                }));
            });
        };
    }
    deleteData(elem) {
        return async () => {
            const answer = await this.notificationService.popup.confirmation("Datensatz löschen", "Soll der Datensatz wirklich gelöscht werden?", [
                { label: "@@actions.no", color: "primary", value: false },
                { label: "@@actions.yes", color: "warn", value: true }
            ]);
            if (answer === true && this.store instanceof PageableCrudStore) {
                await this.store.delete(elem.id);
                await this.store.load();
            }
        };
    }
    static { this.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "16.2.8", ngImport: i0, type: DataTableWidgetComponent, deps: [{ token: i1.MatDialog }, { token: i1$1.AxiosApiClient }, { token: i3.DataStore }, { token: i2.NotificationService }, { token: i3.StoreRegistry }, { token: i5.ActivatedRoute }, { token: i5.Router }, { token: i3.RouterUtilService }, { token: i2.TranslationStore }], target: i0.ɵɵFactoryTarget.Component }); }
    static { this.ɵcmp = i0.ɵɵngDeclareComponent({ minVersion: "14.0.0", version: "16.2.8", type: DataTableWidgetComponent, isStandalone: true, selector: "ng-component", usesInheritance: true, ngImport: i0, template: "<smallstack-loader *ngIf=\"loading; else content\"></smallstack-loader>\n<ng-template #content>\n  <div *ngIf=\"error\">{{ error }}</div>\n  <ng-container *ngIf=\"store; else noStoreConfigured\">\n    <smallstack-list-container [store]=\"store\" [pageSize]=\"data?.setPageSize\" [pageSizeOptions]=\"pageSizeOptions\">\n      <ng-template #content>\n        <div class=\"scrolling-table\">\n          <table mat-table [dataSource]=\"store.currentPage$\" matSort [smallstackMatSortStore]=\"store\" *ngIf=\"!error\">\n            <ng-container [matColumnDef]=\"lp.columnName\" *ngFor=\"let lp of listProperties\">\n              <th\n                mat-header-cell\n                *matHeaderCellDef\n                [class]=\"'header-cell-' + lp.property\"\n                mat-sort-header\n                [disabled]=\"!lp.sortable\"\n              >\n                <ng-container *ngIf=\"lp.title; else noTitle\">{{ lp.title }}</ng-container>\n                <ng-template #noTitle>{{ lp.property | uppercaseSpace }}</ng-template>\n              </th>\n              <td mat-cell *matCellDef=\"let element\" [class]=\"'cell-' + lp.property\">\n                <ng-container [ngSwitch]=\"lp.renderer\">\n                  <ng-container *ngSwitchCase=\"'date'\">\n                    <smallstack-date\n                      [format]=\"lp.rendererDateFormat\"\n                      [timestamp]=\"element[lp.property]\"\n                    ></smallstack-date>\n                  </ng-container>\n                  <ng-container *ngSwitchCase=\"'icon'\">\n                    <div>\n                      <smallstack-icon\n                        size=\"24\"\n                        [alias]=\"\n                          mappingArray[lp.columnName][element[lp.property]]\n                            ? mappingArray[lp.columnName][element[lp.property]]\n                            : lp.defaultIcon\n                        \"\n                      ></smallstack-icon>\n                    </div>\n                  </ng-container>\n                  <ng-container *ngSwitchCase=\"'image'\">\n                    <div class=\"image-preview\" style=\"background-image: url({{ element[lp.property] }});\"></div>\n                  </ng-container>\n                  <ng-container *ngSwitchCase=\"'storeProperty'\">\n                    <smallstack-store-property\n                      [storeName]=\"lp.rendererStorePropertyStore\"\n                      [property]=\"lp.rendererStorePropertyProperty\"\n                      [modelId]=\"element | flatten: lp.property\"\n                    >\n                    </smallstack-store-property>\n                  </ng-container>\n                  <ng-container *ngSwitchCase=\"'i18n'\">\n                    <smallstack-i18n\n                      [data]=\"(lp.i18nPrefix ? lp.i18nPrefix : '') + element[lp.property]\"\n                    ></smallstack-i18n>\n                  </ng-container>\n                  <ng-container *ngSwitchCase=\"'qrCode'\">\n                    <button mat-action-button (click)=\"qrCodeDialog(element[lp.property], lp.qrCodePrefix)\">\n                      <smallstack-icon alias=\"qrcode\"></smallstack-icon>\n                    </button>\n                  </ng-container>\n                  <ng-container *ngSwitchCase=\"'dialog'\">\n                    <button mat-action-button (click)=\"openDialog(lp, element)\">\n                      <smallstack-icon [name]=\"lp.dialogButtonIcon\"></smallstack-icon>\n                    </button>\n                  </ng-container>\n                  <ng-container *ngSwitchCase=\"'link'\">\n                    <a href=\"{{ element[lp.property] }}\" target=\"{{ lp.openLinkInNewWindow ? '_blank' : undefined }}\">\n                      <ng-container *ngIf=\"lp.linkLabel; else noLabel\">\n                        {{ lp.linkLabel }}\n                      </ng-container>\n                      <ng-template #noLabel>\n                        {{ element.link }}\n                      </ng-template>\n                    </a>\n                  </ng-container>\n                  <ng-container *ngSwitchCase=\"'boolean'\">\n                    <smallstack-icon\n                      name=\"checkmark--v1\"\n                      theme=\"color\"\n                      size=\"24\"\n                      *ngIf=\"element[lp.property] === true; else falsy\"\n                    >\n                    </smallstack-icon>\n                    <ng-template #falsy>\n                      <smallstack-icon name=\"delete-sign--v1\" theme=\"color\" size=\"24\"> </smallstack-icon>\n                    </ng-template>\n                  </ng-container>\n                  <ng-container *ngSwitchCase=\"'markdown'\">\n                    <smallstack-markdown-viewer [text]=\"element[lp.property]\"></smallstack-markdown-viewer>\n                  </ng-container>\n                  <ng-container *ngSwitchCase=\"'googleMap'\">\n                    <div style=\"cursor: pointer; position: relative\" (click)=\"overlay.openOverlay()\">\n                      <div style=\"position: absolute; width: 100%; height: 100%; z-index: 100\"></div>\n                      <google-map\n                        [width]=\"lp.googleMapsPreviewWidth\"\n                        [height]=\"lp.googleMapsPreviewHeight\"\n                        [zoom]=\"16\"\n                        [center]=\"convertGeoPointToLatLng(element[lp.property].geoJson)\"\n                        [options]=\"{ gestureHandling: 'none', disableDefaultUI: true }\"\n                      >\n                        <map-marker\n                          [position]=\"convertGeoPointToLatLng(element[lp.property].geoJson)\"\n                          [clickable]=\"false\"\n                        ></map-marker>\n                      </google-map>\n                    </div>\n                    <smallstack-overlay #overlay>\n                      <mat-card appearance=\"outlined\" class=\"flex flex-col space-y-5\">\n                        <google-map\n                          width=\"350px\"\n                          height=\"350px\"\n                          [zoom]=\"16\"\n                          [center]=\"convertGeoPointToLatLng(element[lp.property].geoJson)\"\n                        >\n                          <map-marker\n                            [position]=\"convertGeoPointToLatLng(element[lp.property].geoJson)\"\n                            [clickable]=\"false\"\n                          ></map-marker>\n                        </google-map>\n                        <button (click)=\"overlay.closeOverlay()\" class=\"btn btn-primary\">\n                          <smallstack-i18n data=\"@@actions.close\"></smallstack-i18n>\n                        </button>\n                      </mat-card>\n                    </smallstack-overlay>\n                  </ng-container>\n                  <ng-container *ngSwitchDefault>\n                    {{ element | flatten: lp.property | jsonstring }}\n                  </ng-container>\n                </ng-container>\n              </td>\n            </ng-container>\n            <ng-container matColumnDef=\"actions\" stickyEnd>\n              <th mat-header-cell *matHeaderCellDef class=\"header-cell-actions\">\n                <smallstack-i18n data=\"@@nouns.actions\"></smallstack-i18n>\n              </th>\n              <td mat-cell *matCellDef=\"let element\" class=\"cell-actions\">\n                <ng-container *ngIf=\"data?.showDeleteButton\">\n                  <button\n                    class=\"btn btn-action btn-error\"\n                    [loadingFn]=\"deleteData(element)\"\n                    *showForPermission=\"dataDeletePermission\"\n                  >\n                    <i class=\"fa-regular fa-trash\"></i>\n                  </button>\n                </ng-container>\n                <ng-container *ngIf=\"data?.showEditButton\">\n                  <button\n                    class=\"btn btn-action btn-primary\"\n                    [loadingFn]=\"editData(element)\"\n                    *showForPermission=\"dataEditPermission\"\n                  >\n                    <i class=\"fa-regular fa-pen-to-square\"></i>\n                  </button>\n                </ng-container>\n              </td>\n            </ng-container>\n\n            <tr mat-header-row *matHeaderRowDef=\"columns\"></tr>\n            <tr mat-row *matRowDef=\"let row; columns: columns\"></tr>\n          </table>\n        </div>\n      </ng-template>\n    </smallstack-list-container>\n    <ng-container *ngIf=\"dataType\">\n      <div style=\"text-align: end; padding-top: 20px; padding-right: 15px\" *showForPermission=\"dataCreatePermission\">\n        <button (click)=\"createNew()\" data-test=\"create\" class=\"btn btn-primary\">\n          <smallstack-i18n data=\"@@actions.create\"></smallstack-i18n>\n        </button>\n      </div>\n    </ng-container>\n  </ng-container>\n  <ng-template #noStoreConfigured>\n    <i>no store configured yet</i>\n  </ng-template>\n</ng-template>\n", styles: ["table{width:100%}td{padding:5px!important}td:first-of-type{padding-left:24px!important}.image-preview{width:120px;height:120px;background-size:contain;background-position:center;background-repeat:no-repeat;margin:5px}.cell-actions{white-space:nowrap}\n"], dependencies: [{ kind: "ngmodule", type: CommonModule }, { kind: "directive", type: i6.NgForOf, selector: "[ngFor][ngForOf]", inputs: ["ngForOf", "ngForTrackBy", "ngForTemplate"] }, { kind: "directive", type: i6.NgIf, selector: "[ngIf]", inputs: ["ngIf", "ngIfThen", "ngIfElse"] }, { kind: "directive", type: i6.NgSwitch, selector: "[ngSwitch]", inputs: ["ngSwitch"] }, { kind: "directive", type: i6.NgSwitchCase, selector: "[ngSwitchCase]", inputs: ["ngSwitchCase"] }, { kind: "directive", type: i6.NgSwitchDefault, selector: "[ngSwitchDefault]" }, { kind: "component", type: LoaderComponent, selector: "smallstack-loader", inputs: ["loading", "color", "size", "loadingText"] }, { kind: "component", type: OverlayComponent, selector: "smallstack-overlay", inputs: ["hasBackdrop"] }, { kind: "component", type: ListContainerComponent, selector: "smallstack-list-container", inputs: ["paginatorPosition", "showPager", "pageSize", "pageSizeOptions", "showEmpty", "store"], outputs: ["pageSizeChange"] }, { kind: "pipe", type: UppercaseSpacePipe, name: "uppercaseSpace" }, { kind: "component", type: DateComponent, selector: "smallstack-date", inputs: ["timestamp", "format"] }, { kind: "component", type: IconComponent, selector: "smallstack-icon", inputs: ["theme", "size", "name", "alias", "action", "actionSize", "spinning", "actionSpinning", "color", "themeColor", "actionColor", "badge", "dynamic", "badgeColor"], outputs: ["iconError"] }, { kind: "component", type: I18nComponent, selector: "smallstack-i18n", inputs: ["data", "showMissingKey", "replacers", "locale", "translationStore"] }, { kind: "pipe", type: FlattenPipe, name: "flatten" }, { kind: "pipe", type: JsonStringPipe, name: "jsonstring" }, { kind: "directive", type: LoadingElementDirective, selector: "[loadingFn]", inputs: ["loadingFn", "isLoading"], exportAs: ["loadingFn"] }, { kind: "ngmodule", type: GoogleMapsModule }, { kind: "component", type: i7.GoogleMap, selector: "google-map", inputs: ["height", "width", "mapTypeId", "center", "zoom", "options"], outputs: ["mapInitialized", "authFailure", "boundsChanged", "centerChanged", "mapClick", "mapDblclick", "mapDrag", "mapDragend", "mapDragstart", "headingChanged", "idle", "maptypeidChanged", "mapMousemove", "mapMouseout", "mapMouseover", "projectionChanged", "mapRightclick", "tilesloaded", "tiltChanged", "zoomChanged"], exportAs: ["googleMap"] }, { kind: "directive", type: i7.MapMarker, selector: "map-marker", inputs: ["title", "position", "label", "clickable", "options", "icon", "visible"], outputs: ["animationChanged", "mapClick", "clickableChanged", "cursorChanged", "mapDblclick", "mapDrag", "mapDragend", "draggableChanged", "mapDragstart", "flatChanged", "iconChanged", "mapMousedown", "mapMouseout", "mapMouseover", "mapMouseup", "positionChanged", "mapRightclick", "shapeChanged", "titleChanged", "visibleChanged", "zindexChanged"], exportAs: ["mapMarker"] }, { kind: "ngmodule", type: MatCardModule }, { kind: "component", type: i8.MatCard, selector: "mat-card", inputs: ["appearance"], exportAs: ["matCard"] }, { kind: "component", type: MarkdownViewerComponent, selector: "smallstack-markdown-viewer", inputs: ["text"] }, { kind: "component", type: StorePropertyComponent, selector: "smallstack-store-property", inputs: ["store", "storeName", "modelId", "property", "notFound", "showNotFound"] }, { kind: "ngmodule", type: MatTableModule }, { kind: "component", type: i9.MatTable, selector: "mat-table, table[mat-table]", exportAs: ["matTable"] }, { kind: "directive", type: i9.MatHeaderCellDef, selector: "[matHeaderCellDef]" }, { kind: "directive", type: i9.MatHeaderRowDef, selector: "[matHeaderRowDef]", inputs: ["matHeaderRowDef", "matHeaderRowDefSticky"] }, { kind: "directive", type: i9.MatColumnDef, selector: "[matColumnDef]", inputs: ["sticky", "matColumnDef"] }, { kind: "directive", type: i9.MatCellDef, selector: "[matCellDef]" }, { kind: "directive", type: i9.MatRowDef, selector: "[matRowDef]", inputs: ["matRowDefColumns", "matRowDefWhen"] }, { kind: "directive", type: i9.MatHeaderCell, selector: "mat-header-cell, th[mat-header-cell]" }, { kind: "directive", type: i9.MatCell, selector: "mat-cell, td[mat-cell]" }, { kind: "component", type: i9.MatHeaderRow, selector: "mat-header-row, tr[mat-header-row]", exportAs: ["matHeaderRow"] }, { kind: "component", type: i9.MatRow, selector: "mat-row, tr[mat-row]", exportAs: ["matRow"] }, { kind: "ngmodule", type: MatSortModule }, { kind: "directive", type: i10.MatSort, selector: "[matSort]", inputs: ["matSortDisabled", "matSortActive", "matSortStart", "matSortDirection", "matSortDisableClear"], outputs: ["matSortChange"], exportAs: ["matSort"] }, { kind: "component", type: i10.MatSortHeader, selector: "[mat-sort-header]", inputs: ["disabled", "mat-sort-header", "arrowPosition", "start", "sortActionDescription", "disableClear"], exportAs: ["matSortHeader"] }, { kind: "directive", type: MatSortStoreDirective, selector: "[smallstackMatSortStore]", inputs: ["smallstackMatSortStore"] }, { kind: "directive", type: ShowForPermissionDirective, selector: "[showForPermission]", inputs: ["showForPermission", "showForPermissionTenantId"] }], changeDetection: i0.ChangeDetectionStrategy.OnPush }); }
}
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "16.2.8", ngImport: i0, type: DataTableWidgetComponent, decorators: [{
            type: Component,
            args: [{ changeDetection: ChangeDetectionStrategy.OnPush, standalone: true, imports: [
                        CommonModule,
                        LoaderComponent,
                        OverlayComponent,
                        ListContainerComponent,
                        UppercaseSpacePipe,
                        DateComponent,
                        IconComponent,
                        I18nComponent,
                        FlattenPipe,
                        JsonStringPipe,
                        LoadingElementDirective,
                        GoogleMapsModule,
                        MatCardModule,
                        MarkdownViewerComponent,
                        StorePropertyComponent,
                        MatTableModule,
                        MatSortModule,
                        MatSortStoreDirective,
                        ShowForPermissionDirective
                    ], template: "<smallstack-loader *ngIf=\"loading; else content\"></smallstack-loader>\n<ng-template #content>\n  <div *ngIf=\"error\">{{ error }}</div>\n  <ng-container *ngIf=\"store; else noStoreConfigured\">\n    <smallstack-list-container [store]=\"store\" [pageSize]=\"data?.setPageSize\" [pageSizeOptions]=\"pageSizeOptions\">\n      <ng-template #content>\n        <div class=\"scrolling-table\">\n          <table mat-table [dataSource]=\"store.currentPage$\" matSort [smallstackMatSortStore]=\"store\" *ngIf=\"!error\">\n            <ng-container [matColumnDef]=\"lp.columnName\" *ngFor=\"let lp of listProperties\">\n              <th\n                mat-header-cell\n                *matHeaderCellDef\n                [class]=\"'header-cell-' + lp.property\"\n                mat-sort-header\n                [disabled]=\"!lp.sortable\"\n              >\n                <ng-container *ngIf=\"lp.title; else noTitle\">{{ lp.title }}</ng-container>\n                <ng-template #noTitle>{{ lp.property | uppercaseSpace }}</ng-template>\n              </th>\n              <td mat-cell *matCellDef=\"let element\" [class]=\"'cell-' + lp.property\">\n                <ng-container [ngSwitch]=\"lp.renderer\">\n                  <ng-container *ngSwitchCase=\"'date'\">\n                    <smallstack-date\n                      [format]=\"lp.rendererDateFormat\"\n                      [timestamp]=\"element[lp.property]\"\n                    ></smallstack-date>\n                  </ng-container>\n                  <ng-container *ngSwitchCase=\"'icon'\">\n                    <div>\n                      <smallstack-icon\n                        size=\"24\"\n                        [alias]=\"\n                          mappingArray[lp.columnName][element[lp.property]]\n                            ? mappingArray[lp.columnName][element[lp.property]]\n                            : lp.defaultIcon\n                        \"\n                      ></smallstack-icon>\n                    </div>\n                  </ng-container>\n                  <ng-container *ngSwitchCase=\"'image'\">\n                    <div class=\"image-preview\" style=\"background-image: url({{ element[lp.property] }});\"></div>\n                  </ng-container>\n                  <ng-container *ngSwitchCase=\"'storeProperty'\">\n                    <smallstack-store-property\n                      [storeName]=\"lp.rendererStorePropertyStore\"\n                      [property]=\"lp.rendererStorePropertyProperty\"\n                      [modelId]=\"element | flatten: lp.property\"\n                    >\n                    </smallstack-store-property>\n                  </ng-container>\n                  <ng-container *ngSwitchCase=\"'i18n'\">\n                    <smallstack-i18n\n                      [data]=\"(lp.i18nPrefix ? lp.i18nPrefix : '') + element[lp.property]\"\n                    ></smallstack-i18n>\n                  </ng-container>\n                  <ng-container *ngSwitchCase=\"'qrCode'\">\n                    <button mat-action-button (click)=\"qrCodeDialog(element[lp.property], lp.qrCodePrefix)\">\n                      <smallstack-icon alias=\"qrcode\"></smallstack-icon>\n                    </button>\n                  </ng-container>\n                  <ng-container *ngSwitchCase=\"'dialog'\">\n                    <button mat-action-button (click)=\"openDialog(lp, element)\">\n                      <smallstack-icon [name]=\"lp.dialogButtonIcon\"></smallstack-icon>\n                    </button>\n                  </ng-container>\n                  <ng-container *ngSwitchCase=\"'link'\">\n                    <a href=\"{{ element[lp.property] }}\" target=\"{{ lp.openLinkInNewWindow ? '_blank' : undefined }}\">\n                      <ng-container *ngIf=\"lp.linkLabel; else noLabel\">\n                        {{ lp.linkLabel }}\n                      </ng-container>\n                      <ng-template #noLabel>\n                        {{ element.link }}\n                      </ng-template>\n                    </a>\n                  </ng-container>\n                  <ng-container *ngSwitchCase=\"'boolean'\">\n                    <smallstack-icon\n                      name=\"checkmark--v1\"\n                      theme=\"color\"\n                      size=\"24\"\n                      *ngIf=\"element[lp.property] === true; else falsy\"\n                    >\n                    </smallstack-icon>\n                    <ng-template #falsy>\n                      <smallstack-icon name=\"delete-sign--v1\" theme=\"color\" size=\"24\"> </smallstack-icon>\n                    </ng-template>\n                  </ng-container>\n                  <ng-container *ngSwitchCase=\"'markdown'\">\n                    <smallstack-markdown-viewer [text]=\"element[lp.property]\"></smallstack-markdown-viewer>\n                  </ng-container>\n                  <ng-container *ngSwitchCase=\"'googleMap'\">\n                    <div style=\"cursor: pointer; position: relative\" (click)=\"overlay.openOverlay()\">\n                      <div style=\"position: absolute; width: 100%; height: 100%; z-index: 100\"></div>\n                      <google-map\n                        [width]=\"lp.googleMapsPreviewWidth\"\n                        [height]=\"lp.googleMapsPreviewHeight\"\n                        [zoom]=\"16\"\n                        [center]=\"convertGeoPointToLatLng(element[lp.property].geoJson)\"\n                        [options]=\"{ gestureHandling: 'none', disableDefaultUI: true }\"\n                      >\n                        <map-marker\n                          [position]=\"convertGeoPointToLatLng(element[lp.property].geoJson)\"\n                          [clickable]=\"false\"\n                        ></map-marker>\n                      </google-map>\n                    </div>\n                    <smallstack-overlay #overlay>\n                      <mat-card appearance=\"outlined\" class=\"flex flex-col space-y-5\">\n                        <google-map\n                          width=\"350px\"\n                          height=\"350px\"\n                          [zoom]=\"16\"\n                          [center]=\"convertGeoPointToLatLng(element[lp.property].geoJson)\"\n                        >\n                          <map-marker\n                            [position]=\"convertGeoPointToLatLng(element[lp.property].geoJson)\"\n                            [clickable]=\"false\"\n                          ></map-marker>\n                        </google-map>\n                        <button (click)=\"overlay.closeOverlay()\" class=\"btn btn-primary\">\n                          <smallstack-i18n data=\"@@actions.close\"></smallstack-i18n>\n                        </button>\n                      </mat-card>\n                    </smallstack-overlay>\n                  </ng-container>\n                  <ng-container *ngSwitchDefault>\n                    {{ element | flatten: lp.property | jsonstring }}\n                  </ng-container>\n                </ng-container>\n              </td>\n            </ng-container>\n            <ng-container matColumnDef=\"actions\" stickyEnd>\n              <th mat-header-cell *matHeaderCellDef class=\"header-cell-actions\">\n                <smallstack-i18n data=\"@@nouns.actions\"></smallstack-i18n>\n              </th>\n              <td mat-cell *matCellDef=\"let element\" class=\"cell-actions\">\n                <ng-container *ngIf=\"data?.showDeleteButton\">\n                  <button\n                    class=\"btn btn-action btn-error\"\n                    [loadingFn]=\"deleteData(element)\"\n                    *showForPermission=\"dataDeletePermission\"\n                  >\n                    <i class=\"fa-regular fa-trash\"></i>\n                  </button>\n                </ng-container>\n                <ng-container *ngIf=\"data?.showEditButton\">\n                  <button\n                    class=\"btn btn-action btn-primary\"\n                    [loadingFn]=\"editData(element)\"\n                    *showForPermission=\"dataEditPermission\"\n                  >\n                    <i class=\"fa-regular fa-pen-to-square\"></i>\n                  </button>\n                </ng-container>\n              </td>\n            </ng-container>\n\n            <tr mat-header-row *matHeaderRowDef=\"columns\"></tr>\n            <tr mat-row *matRowDef=\"let row; columns: columns\"></tr>\n          </table>\n        </div>\n      </ng-template>\n    </smallstack-list-container>\n    <ng-container *ngIf=\"dataType\">\n      <div style=\"text-align: end; padding-top: 20px; padding-right: 15px\" *showForPermission=\"dataCreatePermission\">\n        <button (click)=\"createNew()\" data-test=\"create\" class=\"btn btn-primary\">\n          <smallstack-i18n data=\"@@actions.create\"></smallstack-i18n>\n        </button>\n      </div>\n    </ng-container>\n  </ng-container>\n  <ng-template #noStoreConfigured>\n    <i>no store configured yet</i>\n  </ng-template>\n</ng-template>\n", styles: ["table{width:100%}td{padding:5px!important}td:first-of-type{padding-left:24px!important}.image-preview{width:120px;height:120px;background-size:contain;background-position:center;background-repeat:no-repeat;margin:5px}.cell-actions{white-space:nowrap}\n"] }]
        }], ctorParameters: function () { return [{ type: i1.MatDialog }, { type: i1$1.AxiosApiClient }, { type: i3.DataStore }, { type: i2.NotificationService }, { type: i3.StoreRegistry }, { type: i5.ActivatedRoute }, { type: i5.Router }, { type: i3.RouterUtilService }, { type: i2.TranslationStore }]; } });

export { DataTableWidgetComponent };
//# sourceMappingURL=smallstack-data-widgets-data-table-widget.component-18b4424f.mjs.map
