import * as i6 from '@angular/common';
import { CommonModule } from '@angular/common';
import * as i0 from '@angular/core';
import { Component, ChangeDetectionStrategy } from '@angular/core';
import * as i5 from '@angular/router';
import { LoadingElementDirective } from '@smallstack/common-components';
import { LoaderComponent } from '@smallstack/store-components';
import * as i1 from '@smallstack/typesystem-client';
import { convertSortStringToAscDescDictionary, replaceVariablesInObject, isNonEmptyString, cloneObject } from '@smallstack/utils';
import { BaseWidgetComponent, WidgetChildComponent } from '@smallstack/widget-core';
import { filter, switchMap, map, tap } from 'rxjs';

class ReactiveDataWidgetComponent extends BaseWidgetComponent {
    constructor(rxCollectionService, activatedRoute) {
        super();
        this.rxCollectionService = rxCollectionService;
        this.activatedRoute = activatedRoute;
        this.models$ = this.data$.pipe(filter((data) => data?.typePath !== undefined), switchMap(async (data) => {
            const collection = await this.rxCollectionService.getCollection(data.typePath);
            if (data.liveSync === true)
                this.rxCollectionService.activateLiveSync(data.typePath);
            else
                await collection.sync();
            return [data, collection];
        }), filter(([data, collection]) => collection !== undefined), switchMap(([data, collection]) => {
            const query = {};
            if (data.sortBy)
                query.sort = [convertSortStringToAscDescDictionary(data.sortBy)];
            if (data.filter)
                query.selector = replaceVariablesInObject(data.filter, {
                    ...this.context,
                    queryParams: this.activatedRoute.snapshot.queryParams
                });
            return collection.rxCollection.find(query).$;
        }), map((values) => values.map((value) => value.toJSON())), map((values) => {
            if (this.data.findOne === true)
                return values[0];
            return values;
        }), map((values) => {
            if (isNonEmptyString(this.data.contextVariable)) {
                if (this.context === undefined)
                    this.context = {};
                this.context[this.data.contextVariable] = values;
                this.cdr.detectChanges();
                return this.context;
            }
            return values;
        }), tap((values) => {
            this.values = cloneObject(values);
            void this.sendSocketData("data", this.values);
            this.cdr.detectChanges();
        }));
        this.subscription.add(this.models$.subscribe());
    }
    reload() {
        return async () => {
            const collection = await this.rxCollectionService.getCollection(this.data.typePath);
            await collection.cleanAndResync();
        };
    }
    static { this.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "16.2.8", ngImport: i0, type: ReactiveDataWidgetComponent, deps: [{ token: i1.RxCollectionService }, { token: i5.ActivatedRoute }], target: i0.ɵɵFactoryTarget.Component }); }
    static { this.ɵcmp = i0.ɵɵngDeclareComponent({ minVersion: "14.0.0", version: "16.2.8", type: ReactiveDataWidgetComponent, isStandalone: true, selector: "smallstack-reactive-data-widget", usesInheritance: true, ngImport: i0, template: "<!-- TODO: models$ | async does not trigger change detection -->\n<ng-container *ngIf=\"values; else loading\">\n  <smallstack-widget-child\n    [(data)]=\"data\"\n    property=\"component\"\n    (dataChange)=\"dataChange.emit($event)\"\n    [context]=\"values\"\n  ></smallstack-widget-child>\n  <div *ngIf=\"data.showElementCountText\" class=\"flex flex-row justify-center text-sm italic text-gray-400 p-4\"\n    >Es werden {{ values?.length }} Datens\u00E4tze angezeigt</div\n  >\n  <div class=\"flex flex-row justify-end\">\n    <button *ngIf=\"data.showReloadBtn\" class=\"btn btn-outline btn-primary btn-sm m-4\" [loadingFn]=\"reload()\"\n      >Neu laden</button\n    >\n  </div>\n</ng-container>\n<ng-template #loading>\n  <span class=\"component-loading\"></span>\n</ng-template>\n", dependencies: [{ kind: "ngmodule", type: CommonModule }, { kind: "directive", type: i6.NgIf, selector: "[ngIf]", inputs: ["ngIf", "ngIfThen", "ngIfElse"] }, { kind: "component", type: WidgetChildComponent, selector: "smallstack-widget-child", inputs: ["data", "context", "property", "widgetTags"], outputs: ["dataChange"] }, { kind: "directive", type: LoadingElementDirective, selector: "[loadingFn]", inputs: ["loadingFn", "isLoading"], exportAs: ["loadingFn"] }], changeDetection: i0.ChangeDetectionStrategy.OnPush }); }
}
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "16.2.8", ngImport: i0, type: ReactiveDataWidgetComponent, decorators: [{
            type: Component,
            args: [{ selector: "smallstack-reactive-data-widget", changeDetection: ChangeDetectionStrategy.OnPush, standalone: true, imports: [CommonModule, WidgetChildComponent, LoaderComponent, LoadingElementDirective], template: "<!-- TODO: models$ | async does not trigger change detection -->\n<ng-container *ngIf=\"values; else loading\">\n  <smallstack-widget-child\n    [(data)]=\"data\"\n    property=\"component\"\n    (dataChange)=\"dataChange.emit($event)\"\n    [context]=\"values\"\n  ></smallstack-widget-child>\n  <div *ngIf=\"data.showElementCountText\" class=\"flex flex-row justify-center text-sm italic text-gray-400 p-4\"\n    >Es werden {{ values?.length }} Datens\u00E4tze angezeigt</div\n  >\n  <div class=\"flex flex-row justify-end\">\n    <button *ngIf=\"data.showReloadBtn\" class=\"btn btn-outline btn-primary btn-sm m-4\" [loadingFn]=\"reload()\"\n      >Neu laden</button\n    >\n  </div>\n</ng-container>\n<ng-template #loading>\n  <span class=\"component-loading\"></span>\n</ng-template>\n" }]
        }], ctorParameters: function () { return [{ type: i1.RxCollectionService }, { type: i5.ActivatedRoute }]; } });

export { ReactiveDataWidgetComponent };
//# sourceMappingURL=smallstack-data-widgets-reactive-data-widget.component-6d5b6adf.mjs.map
