import * as i0 from '@angular/core';
import { Component, ChangeDetectionStrategy } from '@angular/core';
import { I18nComponent } from '@smallstack/i18n-components';
import * as i1 from '@smallstack/typesystem-client';
import { filterNullish } from '@smallstack/utils';
import { combineLatest, switchMap, of } from 'rxjs';
import { B as BaseViewWidgetComponent } from './smallstack-data-widgets-base-view-widget.component-19f20763.mjs';
import { RxLet } from '@rx-angular/template/let';
import { RxIf } from '@rx-angular/template/if';
import { OverlayComponent } from '@smallstack/common-components';
import { WidgetRendererComponent } from '@smallstack/widget-core';

class SelectViewWidgetComponent extends BaseViewWidgetComponent {
    constructor(rxCollectionService, frontendTypeRegistry) {
        super();
        this.rxCollectionService = rxCollectionService;
        this.frontendTypeRegistry = frontendTypeRegistry;
        this.value$ = combineLatest([this.model$, this.schema$]).pipe(filterNullish(), switchMap(([model, schema]) => {
            if (schema["x-schema-form"]?.["values"]) {
                return of({
                    label: schema["x-schema-form"]?.["values"].find((val) => val.value === model)
                        ?.label
                });
            }
            else if (schema.enum)
                return of(model);
            // if type is given, get entry
            else if (schema["x-schema-form"]?.type) {
                return this.rxCollectionService.getCollection$(schema["x-schema-form"].type).pipe(switchMap(async (collection) => {
                    await collection.replicationState.awaitInSync();
                    return collection;
                }), switchMap((collection) => {
                    return collection.rxCollection.findOne({ selector: { id: model } }).$;
                }), switchMap(async (value) => {
                    if (!value)
                        return { label: "Datensatz mit ID " + model + "wurde nicht gefunden" };
                    const type = await this.frontendTypeRegistry.getTypeByPath(schema["x-schema-form"].type);
                    return {
                        label: this.frontendTypeRegistry.getRepresentation(type, value.toJSON()),
                        linkedModel: value.toJSON(),
                        schema: await this.frontendTypeRegistry.getSchema(type.path)
                    };
                }));
            }
            // else just return value
            return of({ label: model });
        }));
    }
    static { this.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "16.2.8", ngImport: i0, type: SelectViewWidgetComponent, deps: [{ token: i1.RxCollectionService }, { token: i1.FrontendTypeRegistry }], target: i0.ɵɵFactoryTarget.Component }); }
    static { this.ɵcmp = i0.ɵɵngDeclareComponent({ minVersion: "14.0.0", version: "16.2.8", type: SelectViewWidgetComponent, isStandalone: true, selector: "smallstack-select-view-widget", usesInheritance: true, ngImport: i0, template: "<ng-container *rxLet=\"value$; let value\">\n  <ng-container *rxIf=\"value?.linkedModel; else default\">\n    <span class=\"border-dashed border-b cursor-pointer\" (click)=\"overlay.openOverlay()\"\n      ><smallstack-i18n [data]=\"value.label\"></smallstack-i18n\n    ></span>\n    <smallstack-overlay #overlay>\n      <div class=\"card card-bordered bg-white shadow-lg p-1 overflow-auto\">\n        <smallstack-widget-renderer\n          [widget]=\"{ name: 'DefaultDetailsView' }\"\n          [context]=\"{ model: value.linkedModel, schema: value.schema }\"\n        ></smallstack-widget-renderer>\n      </div>\n    </smallstack-overlay>\n  </ng-container>\n\n  <ng-template #default>\n    <smallstack-i18n [data]=\"value?.label\"></smallstack-i18n>\n  </ng-template>\n</ng-container>\n", dependencies: [{ kind: "component", type: I18nComponent, selector: "smallstack-i18n", inputs: ["data", "showMissingKey", "replacers", "locale", "translationStore"] }, { kind: "directive", type: RxLet, selector: "[rxLet]", inputs: ["rxLet", "rxLetStrategy", "rxLetComplete", "rxLetError", "rxLetSuspense", "rxLetContextTrigger", "rxLetCompleteTrigger", "rxLetErrorTrigger", "rxLetSuspenseTrigger", "rxLetNextTrigger", "rxLetRenderCallback", "rxLetParent", "rxLetPatchZone"], outputs: ["rendered"] }, { kind: "directive", type: RxIf, selector: "[rxIf]", inputs: ["rxIf", "rxIfStrategy", "rxIfElse", "rxIfThen", "rxIfSuspense", "rxIfComplete", "rxIfError", "rxIfContextTrigger", "rxIfNextTrigger", "rxIfSuspenseTrigger", "rxIfErrorTrigger", "rxIfCompleteTrigger", "rxIfParent", "rxIfPatchZone", "rxIfRenderCallback"] }, { kind: "component", type: OverlayComponent, selector: "smallstack-overlay", inputs: ["hasBackdrop"] }, { kind: "component", type: WidgetRendererComponent, selector: "smallstack-widget-renderer", inputs: ["widget", "additionalProviders", "context", "class"], outputs: ["widgetChange"] }], changeDetection: i0.ChangeDetectionStrategy.OnPush }); }
}
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "16.2.8", ngImport: i0, type: SelectViewWidgetComponent, decorators: [{
            type: Component,
            args: [{ selector: "smallstack-select-view-widget", standalone: true, imports: [I18nComponent, RxLet, RxIf, OverlayComponent, WidgetRendererComponent], changeDetection: ChangeDetectionStrategy.OnPush, template: "<ng-container *rxLet=\"value$; let value\">\n  <ng-container *rxIf=\"value?.linkedModel; else default\">\n    <span class=\"border-dashed border-b cursor-pointer\" (click)=\"overlay.openOverlay()\"\n      ><smallstack-i18n [data]=\"value.label\"></smallstack-i18n\n    ></span>\n    <smallstack-overlay #overlay>\n      <div class=\"card card-bordered bg-white shadow-lg p-1 overflow-auto\">\n        <smallstack-widget-renderer\n          [widget]=\"{ name: 'DefaultDetailsView' }\"\n          [context]=\"{ model: value.linkedModel, schema: value.schema }\"\n        ></smallstack-widget-renderer>\n      </div>\n    </smallstack-overlay>\n  </ng-container>\n\n  <ng-template #default>\n    <smallstack-i18n [data]=\"value?.label\"></smallstack-i18n>\n  </ng-template>\n</ng-container>\n" }]
        }], ctorParameters: function () { return [{ type: i1.RxCollectionService }, { type: i1.FrontendTypeRegistry }]; } });

export { SelectViewWidgetComponent };
//# sourceMappingURL=smallstack-data-widgets-select-view-widget.component-710027d8.mjs.map
