import { WIDGET_FORM_INPUT_I18N, WIDGET_VIEW_ARRAY, WIDGET_VIEW_BOOLEAN, WIDGET_VIEW_I18N, WIDGET_VIEW_LINKS, WIDGET_VIEW_NUMBER, WIDGET_VIEW_OBJECT, WIDGET_VIEW_SELECT, WIDGET_VIEW_STRING, WIDGET_VIEW_DATE_TIME } from '@smallstack/core-common';
import { WidgetTag, AllWidgetTags } from '@smallstack/widget-core';
import { SocketDtoDirectionEnum, SocketDtoTypeEnum } from '@smallstack/axios-api-client';
import { FORM_INPUT_TYPES, FORM_INPUT_MONACO } from '@smallstack/form-shared';

const CalendarWidget = {
    name: "Calendar",
    configuration: () => import('./smallstack-data-widgets-configuration-3d60f8a3.mjs').then((m) => m.CalendarWidgetConfiguration),
    component: () => import('./smallstack-data-widgets-calendar-widget.component-78c4bece.mjs').then((m) => m.CalendarWidgetComponent)
};

const ContextManipulationWidget = {
    name: "ContextManipulation",
    configuration: () => import('./smallstack-data-widgets-configuration-78ce1a4a.mjs').then((m) => m.ContextManipulationWidgetConfiguration),
    component: () => import('./smallstack-data-widgets-context-manipulation-widget.component-a081e191.mjs').then((m) => m.ContextManipulationWidgetComponent)
};

const ContextTableWidget = {
    name: "ContextTable",
    configuration: () => import('./smallstack-data-widgets-configuration-00f1980e.mjs').then((m) => m.ContextTableWidgetConfiguration),
    component: () => import('./smallstack-data-widgets-context-table-widget.component-30c89694.mjs').then((m) => m.ContextTableWidgetComponent)
};

const DataExportWidget = {
    name: "DataExportWidget",
    configuration: () => import('./smallstack-data-widgets-configuration-1105b0cc.mjs').then((m) => m.DataExportWidgetConfiguration),
    component: () => import('./smallstack-data-widgets-data-export-widget.component-f46aaea8.mjs').then((m) => m.DataExportWidgetComponent)
};

const DataTableWidget = {
    name: "DataTable",
    configuration: () => import('./smallstack-data-widgets-configuration-fb0a53c4.mjs').then((m) => m.Configuration),
    component: () => import('./smallstack-data-widgets-data-table-widget.component-18b4424f.mjs').then((m) => m.DataTableWidgetComponent)
};

const SocketNames = {
    openCreationDialog: "openCreationDialog",
    tableData: "tableData",
    searchQuery: "searchQuery",
    reload: "reload"
};
const DataTableWidgetV2 = {
    name: "DataTableV2",
    configuration: () => import('./smallstack-data-widgets-data-table-v2-widget-configuration-f344179a.mjs').then((m) => m.DataTableV2Configuration),
    component: () => import('./smallstack-data-widgets-data-table-v2-widget.component-345bdb36.mjs').then((m) => m.DataTableV2WidgetComponent)
};

const DataTableWidgetV3 = {
    name: "DataTableV3",
    configuration: () => import('./smallstack-data-widgets-data-table-v3-widget-configuration-deba1f67.mjs').then((m) => m.DataTableV3Configuration),
    component: () => import('./smallstack-data-widgets-data-table-v3-widget.component-5ec66464.mjs').then((m) => m.DataTableV3WidgetComponent)
};

const DefaultDetailsViewWidget = {
    name: "DefaultDetailsView",
    component: () => import('./smallstack-data-widgets-default-details-view-widget.component-bf89fb6e.mjs').then((m) => m.DefaultDetailsViewWidgetComponent),
    configuration: {
        templateName: "Detail Anzeige",
        templateDescription: "Zeigt Details einer Entität an."
    }
};

const FilesWidget = {
    name: "Files",
    configuration: {
        templateName: "Dateien",
        templateDescription: "Zeigt Dateien an, welche auf dem aktuellen Kontext liegen",
        icon: "folder-invoices--v1",
        dataSchema: {
            type: "object",
            properties: {
                contextProperty: {
                    title: "Kontext Variable",
                    description: "Geben Sie hier an, wo sich die Dateien im aktuellen Kontext befinden",
                    type: "string",
                    default: "fileIds"
                },
                noFilesFoundText: {
                    title: "Keine Dateien gefunden Text",
                    description: "Wird angezeigt, wenn keine Dateien gefunden wurden",
                    type: "array",
                    "x-schema-form": {
                        inputWidget: WIDGET_FORM_INPUT_I18N
                    }
                }
            }
        },
        tags: [WidgetTag.APPLICATION, WidgetTag.CBO, WidgetTag.CMS]
    },
    component: () => import('./smallstack-data-widgets-files-widget.component-7d9c7a2a.mjs').then((m) => m.FilesWidgetComponent)
};

const HttpRequestBtnWidget = {
    name: "HttpRequestButton",
    component: () => import('./smallstack-data-widgets-http-request-btn-widget.component-2f5795f3.mjs').then((m) => m.HttpRequestBtnWidgetComponent),
    configuration: () => import('./smallstack-data-widgets-configuration-7d9aa849.mjs').then((m) => m.HttpRequestBtnWidgetConfiguration)
};

const OfflineSearchWidget = {
    name: "OfflineSearch",
    configuration: {
        templateName: "Offline Suche",
        templateDescription: "Sucht in der lokalen (offline) Datenbank im Browser",
        tags: AllWidgetTags,
        icon: "search",
        dataSchema: {
            type: "object",
            properties: {
                typePath: {
                    title: "Datentyp",
                    type: "string",
                    "x-schema-form": { widget: FORM_INPUT_TYPES }
                },
                executeOnLoad: {
                    title: "Suche beim Laden sofort ausführen",
                    type: "boolean",
                    default: false,
                    description: "Wenn aktiviert, wird die Suche sofort ausgeführt, wenn die Seite geladen wird."
                }
            }
        },
        sockets: [
            { direction: SocketDtoDirectionEnum.Out, name: "models", type: SocketDtoTypeEnum.Objectarray },
            { direction: SocketDtoDirectionEnum.Out, name: "focused", type: SocketDtoTypeEnum.Undefined }
        ]
    },
    component: () => import('./smallstack-data-widgets-offline-search-widget.component-ba1165eb.mjs').then((m) => m.OfflineSearchWidgetComponent)
};

const OpenEditorBtnWidget = {
    name: "OpenEditorBtn",
    component: () => import('./smallstack-data-widgets-open-editor-btn-widget.component-256f5da2.mjs').then((m) => m.OpenEditorBtnWidgetComponent),
    configuration: {
        templateName: "Editor öffnen Button",
        templateDescription: "Öffnet einen Dialog mit einem Editor, entweder zum Bearbeiten oder zum Anlegen einer Entität.",
        icon: "task",
        dataSchema: {
            type: "object",
            properties: {
                type: {
                    type: "string",
                    title: "Datentyp",
                    "x-schema-form": {
                        widget: "types"
                    }
                },
                contextProperty: {
                    type: "string",
                    title: "Kontext Variable"
                },
                icon: {
                    type: "string",
                    title: "Icon",
                    "x-schema-form": {
                        widget: "icon"
                    }
                },
                text: {
                    type: "string",
                    title: "Text"
                },
                btnAsBlock: {
                    type: "boolean",
                    title: "Button auf voller Breite"
                }
            }
        }
    }
};

const ReactiveDataWidget = {
    name: "ReactiveData",
    configuration: {
        templateName: "Reaktive Daten",
        templateDescription: "Stellt Daten via Kontext bereit. Sobald sich die Daten auf dem Server ändern, wird der Kontext aktualisiert.",
        tags: AllWidgetTags,
        icon: "data-configuration",
        dataSchema: {
            type: "object",
            properties: {
                typePath: {
                    title: "Datentyp",
                    type: "string",
                    "x-schema-form": { widget: FORM_INPUT_TYPES, group: "Datenquelle" }
                },
                filter: {
                    type: "object",
                    title: "Filter",
                    description: "Mango Query Syntax, siehe https://github.com/cloudant/mango#json-syntax-descriptions. Query Parameter sind im Unterobjekt 'query' zu finden.",
                    "x-schema-form": { widget: FORM_INPUT_MONACO, monacoLanguage: "json", group: "Datenquelle" }
                },
                sortBy: {
                    title: "Sortierung",
                    description: "Geben Sie hier eine Eigenschaft an, nach welcher Sie sortieren möchten.",
                    type: "string",
                    default: "-createdAt",
                    "x-schema-form": { group: "Datenquelle" }
                },
                findOne: {
                    title: "Einzelnes Objekt",
                    description: "Falls aktiv, dann wird das erste Objekt anstatt der kompletten Liste weitergeben",
                    type: "boolean",
                    "x-schema-form": { group: "Datenquelle" }
                },
                contextVariable: {
                    title: "Kontext Variable",
                    type: "string",
                    description: "In diese Kontext Variable wird der Inhalt geschrieben. Leer lassen für Root.",
                    "x-schema-form": { group: "Datenquelle" }
                },
                liveSync: {
                    title: "Automatisch aktualisieren",
                    type: "boolean",
                    description: "Falls aktiviert, dann werden Änderungen, die im Backoffice vorgenommen werden, sofort live in der App aktualisiert.",
                    "x-schema-form": { group: "Datenquelle" }
                },
                component: {
                    title: "Komponente",
                    type: "object",
                    "x-schema-form": { widget: "widget", group: "Anzeige" }
                },
                showElementCountText: {
                    title: "Zeige Elemente Anzahl",
                    description: "Falls aktiv, dann wird der Text 'Es werden XXX Datensätze angezeigt' unterhalb der Komponente angezeigt.",
                    type: "boolean",
                    "x-schema-form": { group: "Anzeige" }
                },
                showReloadBtn: {
                    title: "Zeige Neu Laden Button",
                    description: "Falls aktiv, dann wird ein 'Neu Laden' Button angezeigt, mit welchem der Benutzer alle Datensätze aktiv neu laden kann.",
                    type: "boolean",
                    "x-schema-form": { group: "Anzeige" }
                }
            }
        },
        sockets: [
            {
                direction: SocketDtoDirectionEnum.Out,
                name: "data",
                type: SocketDtoTypeEnum.Stringarray
            }
        ]
    },
    component: () => import('./smallstack-data-widgets-reactive-data-widget.component-6d5b6adf.mjs').then((m) => m.ReactiveDataWidgetComponent)
};

const StoreConfiguratorWidget = {
    name: "StoreConfigurator",
    configuration: {
        templateName: "Store Konfiguration",
        templateDescription: "Kann verwendet werden, um einen globalen Store zu konfigurieren",
        icon: "data-configuration",
        tags: AllWidgetTags,
        dataSchema: {
            type: "object",
            properties: {
                typePath: {
                    type: "string",
                    title: "Datentyp",
                    "x-schema-form": {
                        widget: "types"
                    }
                },
                loadStoreOnPageLoad: {
                    type: "boolean",
                    default: false,
                    title: "Store bei Seitenaufruf laden?"
                },
                resetStoreOnPageLoad: {
                    type: "boolean",
                    default: false,
                    title: "Store beim Seitenaufruf zurücksetzen?",
                    description: ""
                }
            }
        }
    },
    component: () => import('./smallstack-data-widgets-store-configurator-widget.component-992bd334.mjs').then((m) => m.StoreConfiguratorWidgetComponent)
};

const SyncStatusWidget = {
    name: "SyncStatus",
    configuration: {
        templateName: "Offline Synchronisierungsstatus",
        templateDescription: "Zeigt den Status aller Offline Synchronisierungen an",
        icon: "synchronize--v1",
        tags: AllWidgetTags
    },
    component: () => import('./smallstack-data-widgets-sync-status-widget.component-f4f8fd20.mjs').then((m) => m.SyncStatusWidgetComponent)
};

const TableWidget = {
    name: "Table",
    configuration: {
        templateName: "Tabelle",
        templateDescription: "Zeigt eine einfach Tabelle an.",
        icon: "grid",
        configuration: {
            type: "object",
            properties: {
                rows: {
                    title: "Anzahl Zeilen",
                    description: "Geben Sie hier die Anzahl der Zeilen an.",
                    type: "number",
                    default: 2
                },
                cols: {
                    title: "Anzahl Spalten",
                    description: "Geben Sie hier die Anzahl der Spalten pro Zeile an.",
                    type: "number",
                    default: 2
                },
                tableSpacing: {
                    title: "Tabellenabstände außen",
                    description: "Geben Sie hier an, wie die Abstände um die einzelnen Zellen in der Tabelle sein sollen. Angaben in px.",
                    type: "string",
                    default: "0px 0px"
                },
                tablePadding: {
                    title: "Tabellenabstände innen",
                    description: "Geben Sie hier an, wie die Abstände innerhalb der einzelnen Tabellen-Zellen sein sollen. Angaben in px.",
                    type: "string",
                    default: "4px 8px"
                },
                tableBorder: {
                    title: "Tabellenrahmenoptionen",
                    description: "Geben Sie hier an, ob die Tabelle einen Rahmen haben soll.",
                    type: "boolean",
                    default: false
                },
                tdVerticalAlign: {
                    title: "Vertikale Zellenausrichtung",
                    description: "Wie soll der Inhalt in der Zelle vertikal ausgerichtet sein?",
                    enum: ["top", "middle", "bottom"],
                    default: "middle"
                }
            },
            allOf: [
                {
                    if: {
                        properties: {
                            tableBorder: { const: true }
                        }
                    },
                    then: {
                        properties: {
                            tableBorderStyle: {
                                title: "Tabellenrahmenstil",
                                description: "Geben Sie hier an, welchen Rahmenstil die Tabelle haben soll.",
                                type: "string",
                                enum: ["none", "solid", "dashed", "dotted"],
                                default: "solid"
                            },
                            tableBorderWidth: {
                                title: "Tabellenrahmendicke",
                                description: "Geben Sie hier an, wie dick der Rahmen der Tabelle sein soll.",
                                type: "string",
                                default: "2px"
                            },
                            tableBorderColor: {
                                title: "Tabellenrahmenfarbe",
                                description: "Geben Sie hier an, welche Farbe der Rahmen der Tabelle haben soll.",
                                type: "object",
                                "x-schema-form": {
                                    widget: "color"
                                }
                            },
                            tableBorderCollapse: {
                                title: "Doppelte Tabellenrahmen",
                                description: "Geben Sie hier an, ob jede Tabellenzelle einen eigenen Rahmen haben soll.",
                                type: "boolean",
                                default: false
                            }
                        }
                    }
                }
            ]
        },
        tags: AllWidgetTags
    },
    component: () => import('./smallstack-data-widgets-table-widget.component-33cbf184.mjs').then((tw) => tw.TableWidgetComponent)
};

const ArrayViewWidget = {
    name: WIDGET_VIEW_ARRAY,
    component: () => import('./smallstack-data-widgets-array-view-widget.component-3089f03d.mjs').then((m) => m.ArrayViewWidgetComponent)
};

const BooleanViewWidget = {
    name: WIDGET_VIEW_BOOLEAN,
    component: () => import('./smallstack-data-widgets-boolean-view-widget.component-fe4c6df8.mjs').then((m) => m.BooleanViewWidgetComponent)
};

const I18nViewWidget = {
    name: WIDGET_VIEW_I18N,
    component: () => import('./smallstack-data-widgets-i18n-view-widget.component-7c590413.mjs').then((m) => m.I18nViewWidgetComponent)
};

const LinksViewWidget = {
    name: WIDGET_VIEW_LINKS,
    component: () => import('./smallstack-data-widgets-links-view-widget.component-f8415fdb.mjs').then((m) => m.LinksViewWidgetComponent)
};

const NumberViewWidget = {
    name: WIDGET_VIEW_NUMBER,
    component: () => import('./smallstack-data-widgets-number-view-widget.component-80b9feda.mjs').then((m) => m.NumberViewWidgetComponent)
};

const ObjectViewWidget = {
    name: WIDGET_VIEW_OBJECT,
    component: () => import('./smallstack-data-widgets-object-view-widget.component-04b2f171.mjs').then((m) => m.ObjectViewWidgetComponent)
};

const SelectViewWidget = {
    name: WIDGET_VIEW_SELECT,
    component: () => import('./smallstack-data-widgets-select-view-widget.component-710027d8.mjs').then((m) => m.SelectViewWidgetComponent)
};

const StringViewWidget = {
    name: WIDGET_VIEW_STRING,
    component: () => import('./smallstack-data-widgets-string-view-widget.component-b8316252.mjs').then((m) => m.StringViewWidgetComponent)
};

const OpenDetailsBtnWidget = {
    name: "OpenDetailsBtn",
    component: () => import('./smallstack-data-widgets-open-details-btn-widget.component-c4982655.mjs').then((m) => m.OpenDetailsBtnWidgetComponent),
    configuration: {
        templateName: "Details öffnen Button",
        templateDescription: "Öffnet einen Dialog mit Details einer Entität.",
        icon: "task",
        dataSchema: {
            type: "object",
            properties: {
                type: {
                    type: "string",
                    title: "Datentyp",
                    "x-schema-form": {
                        widget: "types"
                    }
                },
                contextProperty: {
                    type: "string",
                    title: "Kontext Variable"
                },
                icon: {
                    type: "string",
                    title: "Icon",
                    "x-schema-form": {
                        widget: "icon"
                    }
                },
                text: {
                    type: "string",
                    title: "Text"
                },
                btnAsBlock: {
                    type: "boolean",
                    title: "Button auf voller Breite"
                }
            }
        }
    }
};

const DateTimeViewWidget = {
    name: WIDGET_VIEW_DATE_TIME,
    component: () => import('./smallstack-data-widgets-date-time-view-widget.component-af79c3b0.mjs').then((m) => m.DateTimeViewWidgetComponent)
};

function addDataWidgets(widgetRegistry) {
    widgetRegistry.addWidget(CalendarWidget);
    widgetRegistry.addWidget(ContextManipulationWidget);
    widgetRegistry.addWidget(ContextTableWidget);
    widgetRegistry.addWidget(DataExportWidget);
    widgetRegistry.addWidget(DataTableWidget);
    widgetRegistry.addWidget(DataTableWidgetV2);
    widgetRegistry.addWidget(DataTableWidgetV3);
    widgetRegistry.addWidget(FilesWidget);
    widgetRegistry.addWidget(HttpRequestBtnWidget);
    widgetRegistry.addWidget(OfflineSearchWidget);
    widgetRegistry.addWidget(ReactiveDataWidget);
    widgetRegistry.addWidget(StoreConfiguratorWidget);
    widgetRegistry.addWidget(SyncStatusWidget);
    widgetRegistry.addWidget(TableWidget);
    widgetRegistry.addWidget(DefaultDetailsViewWidget);
    widgetRegistry.addWidget(StringViewWidget);
    widgetRegistry.addWidget(I18nViewWidget);
    widgetRegistry.addWidget(BooleanViewWidget);
    widgetRegistry.addWidget(ArrayViewWidget);
    widgetRegistry.addWidget(NumberViewWidget);
    widgetRegistry.addWidget(ObjectViewWidget);
    widgetRegistry.addWidget(LinksViewWidget);
    widgetRegistry.addWidget(SelectViewWidget);
    widgetRegistry.addWidget(OpenEditorBtnWidget);
    widgetRegistry.addWidget(OpenDetailsBtnWidget);
    widgetRegistry.addWidget(DateTimeViewWidget);
}

/**
 * Generated bundle index. Do not edit.
 */

export { SocketNames as S, addDataWidgets as a };
//# sourceMappingURL=smallstack-data-widgets-smallstack-data-widgets-fa483882.mjs.map
