import { MatDialog } from "@angular/material/dialog";
import { ActivatedRoute } from "@angular/router";
import { WidgetDto } from "@smallstack/axios-api-client";
import { BreakpointService, FrontendSmallstackType, RouterUtilService, StoreRegistry } from "@smallstack/common-components";
import { NotificationService } from "@smallstack/i18n-components";
import { PageableCrudStore, PageableStore } from "@smallstack/store";
import { FrontendTypeRegistry } from "@smallstack/typesystem-client";
import { SmallstackTypeSchema } from "@smallstack/typesystem";
import { convertGeoPointToLatLng } from "@smallstack/utils";
import { BaseWidgetComponent, SocketAwareWidget, WidgetTag } from "@smallstack/widget-core";
import { BehaviorSubject } from "rxjs";
import * as i0 from "@angular/core";
export interface DataTableV2ListProperty {
    columnName: string;
    index: number;
    property: string;
    title?: string;
    sortable: boolean;
    renderer: string;
    rendererDateFormat?: string;
    rendererStorePropertyProperty?: string;
    rendererStorePropertyStore?: string;
    qrCodePrefix?: string;
    dialogButtonIcon?: string;
    dialogWidth?: string;
    dialogHeight?: string;
    dialogComponent?: WidgetDto;
    dialogUrlSyncParameter?: string;
    linkLabel?: string;
    openLinkInNewWindow?: boolean;
    valueIconPairArray?: [{
        value: string;
        icon: string;
    }];
    defaultIcon?: string;
    mappingArray?: [{
        value: string;
        mappedValue: string;
    }];
    defaultValue?: string;
    i18nPrefix?: string;
    googleMapsPreviewHeight?: number;
    googleMapsPreviewWidth?: number;
    widget?: WidgetDto;
    widgetContextType?: "property" | "full";
    currency?: string;
}
export declare class DataTableV2WidgetComponent extends BaseWidgetComponent implements SocketAwareWidget {
    private matDialog;
    private notificationService;
    private storeRegistry;
    private activatedRoute;
    private routerUtilService;
    private frontendTypeRegistry;
    convertGeoPointToLatLng: typeof convertGeoPointToLatLng;
    googleMapsOverlayOpened: boolean;
    store: PageableCrudStore | PageableStore;
    smallstackType: FrontendSmallstackType;
    schema: SmallstackTypeSchema;
    listProperties: DataTableV2ListProperty[];
    loading: boolean;
    errors: string[];
    mappingArray: {
        [columnName: string]: {
            [value: string]: string;
        };
    };
    pageSizeOptions: number[];
    selectedIds: string[];
    selectedModels: any[];
    WidgetTag: typeof WidgetTag;
    protected isMobile$: BehaviorSubject<boolean>;
    protected manualTableData: any[];
    get columns(): string[];
    constructor(matDialog: MatDialog, notificationService: NotificationService, storeRegistry: StoreRegistry, activatedRoute: ActivatedRoute, routerUtilService: RouterUtilService, frontendTypeRegistry: FrontendTypeRegistry, breakPointService: BreakpointService);
    setData(data: any): Promise<void>;
    handleSocketData(socketName: string, data?: unknown): Promise<void>;
    qrCodeDialog(value: string, prefix?: string): void;
    openDialog(lp: DataTableV2ListProperty, model: {
        id: string;
        [key: string]: unknown;
    }): Promise<void>;
    openEditor(model?: any): () => Promise<void>;
    deleteData(elem: {
        id: string;
    }): () => Promise<void>;
    deleteManyData(ids: string[]): () => Promise<void>;
    protected toggleAll(checkboxEvent: Event): Promise<void>;
    protected toggleEntry(id: string, checkboxEvent: Event): void;
    protected setWidgetListProperty(propertyName: string, newWidget: WidgetDto): void;
    private evaluateConfiguration;
    static ɵfac: i0.ɵɵFactoryDeclaration<DataTableV2WidgetComponent, never>;
    static ɵcmp: i0.ɵɵComponentDeclaration<DataTableV2WidgetComponent, "ng-component", never, {}, {}, never, never, true, never>;
}
