import { OnInit } from "@angular/core";
import { MatDialog } from "@angular/material/dialog";
import { ActivatedRoute, Router } from "@angular/router";
import { AxiosApiClient, DataTypeDto, WidgetDto } from "@smallstack/axios-api-client";
import { DataStore, RouterUtilService, StoreRegistry } from "@smallstack/common-components";
import { NotificationService, TranslationStore } from "@smallstack/i18n-components";
import { PageableCrudStore, PageableStore } from "@smallstack/store";
import { convertGeoPointToLatLng } from "@smallstack/utils";
import { BaseWidgetComponent, SocketAwareWidget } from "@smallstack/widget-core";
import * as i0 from "@angular/core";
export interface DataTableListProperty {
    columnName: string;
    property: string;
    title?: string;
    sortable: boolean;
    renderer: string;
    rendererDateFormat?: string;
    rendererStorePropertyProperty?: string;
    rendererStorePropertyStore?: string;
    qrCodePrefix?: string;
    dialogButtonIcon?: string;
    dialogWidth?: string;
    dialogHeight?: string;
    dialogComponent?: WidgetDto;
    dialogUrlSyncParameter?: string;
    linkLabel?: string;
    openLinkInNewWindow?: boolean;
    valueIconPairArray?: [{
        value: string;
        icon: string;
    }];
    defaultIcon?: string;
    i18nPrefix?: string;
    googleMapsPreviewHeight: number;
    googleMapsPreviewWidth: number;
}
export declare class DataTableWidgetComponent extends BaseWidgetComponent implements OnInit, SocketAwareWidget {
    private matDialog;
    private axiosApiClient;
    private dataStore;
    private notificationService;
    private storeRegistry;
    private activatedRoute;
    private router;
    private routerUtilService;
    private translationStore;
    convertGeoPointToLatLng: typeof convertGeoPointToLatLng;
    googleMapsOverlayOpened: boolean;
    store: PageableCrudStore | PageableStore;
    dataType: DataTypeDto;
    listProperties: DataTableListProperty[];
    loading: boolean;
    error: string;
    dataDeletePermission: string;
    dataEditPermission: string;
    dataCreatePermission: string;
    mappingArray: {
        [columnName: string]: {
            [value: string]: string;
        };
    };
    pageSizeOptions: number[];
    constructor(matDialog: MatDialog, axiosApiClient: AxiosApiClient, dataStore: DataStore, notificationService: NotificationService, storeRegistry: StoreRegistry, activatedRoute: ActivatedRoute, router: Router, routerUtilService: RouterUtilService, translationStore: TranslationStore);
    get columns(): string[];
    handleSocketData(socketName: string, data?: unknown): Promise<void>;
    ngOnInit(): Promise<void>;
    qrCodeDialog(value: string, prefix?: string): void;
    openDialog(lp: DataTableListProperty, model: {
        id: string;
        [key: string]: unknown;
    }): Promise<void>;
    createNew(): void;
    editData(model: unknown): () => Promise<void>;
    deleteData(elem: {
        id: string;
    }): () => Promise<void>;
    static ɵfac: i0.ɵɵFactoryDeclaration<DataTableWidgetComponent, never>;
    static ɵcmp: i0.ɵɵComponentDeclaration<DataTableWidgetComponent, "ng-component", never, {}, {}, never, never, true, never>;
}
